"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .networktoken import NetworkToken, NetworkTokenTypedDict
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CollectionNoCursorNetworkTokenTypedDict(TypedDict):
    items: List[NetworkTokenTypedDict]
    r"""A list of items returned for this request."""


class CollectionNoCursorNetworkToken(BaseModel):
    items: List[NetworkToken]
    r"""A list of items returned for this request."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .annotations import get_discriminator
from .datetimes import parse_datetime
from .enums import OpenEnumMeta
from .headers import get_headers, get_response_headers
from .metadata import (
    FieldMetadata,
    find_metadata,
    FormMetadata,
    HeaderMetadata,
    MultipartFormMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
    SecurityMetadata,
)
from .queryparams import get_query_params
from .retries import BackoffStrategy, Retries, retry, retry_async, RetryConfig
from .requestbodies import serialize_request_body, SerializedRequestBody
from .security import get_security, get_security_from_env

from .serializers import (
    get_pydantic_model,
    marshal_json,
    unmarshal,
    unmarshal_json,
    serialize_decimal,
    serialize_float,
    serialize_int,
    stream_to_text,
    stream_to_text_async,
    stream_to_bytes,
    stream_to_bytes_async,
    validate_const,
    validate_decimal,
    validate_float,
    validate_int,
    validate_open_enum,
)
from .url import generate_url, template_url, remove_suffix
from .values import (
    get_global_from_env,
    match_content_type,
    match_status_codes,
    match_response,
    cast_partial,
)
from .logger import Logger, get_body_content, get_default_logger

__all__ = [
    "BackoffStrategy",
    "FieldMetadata",
    "find_metadata",
    "FormMetadata",
    "generate_url",
    "get_body_content",
    "get_default_logger",
    "get_discriminator",
    "get_global_from_env",
    "get_headers",
    "get_pydantic_model",
    "get_query_params",
    "get_response_headers",
    "get_security",
    "get_security_from_env",
    "HeaderMetadata",
    "Logger",
    "marshal_json",
    "match_content_type",
    "match_status_codes",
    "match_response",
    "MultipartFormMetadata",
    "OpenEnumMeta",
    "PathParamMetadata",
    "QueryParamMetadata",
    "remove_suffix",
    "Retries",
    "retry",
    "retry_async",
    "RetryConfig",
    "RequestMetadata",
    "SecurityMetadata",
    "serialize_decimal",
    "serialize_float",
    "serialize_int",
    "serialize_request_body",
    "SerializedRequestBody",
    "stream_to_text",
    "stream_to_text_async",
    "stream_to_bytes",
    "stream_to_bytes_async",
    "template_url",
    "unmarshal",
    "unmarshal_json",
    "validate_decimal",
    "validate_const",
    "validate_float",
    "validate_int",
    "validate_open_enum",
    "cast_partial",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
from gr4vy import models, utils
from gr4vy._hooks import SDKHooks
from gr4vy.account_updater import AccountUpdater
from gr4vy.audit_logs import AuditLogs
from gr4vy.buyers import Buyers
from gr4vy.card_scheme_definitions import CardSchemeDefinitions
from gr4vy.checkout_sessions import CheckoutSessions
from gr4vy.digital_wallets import DigitalWallets
from gr4vy.gift_cards import GiftCards
from gr4vy.merchant_accounts import MerchantAccounts
from gr4vy.models import internal
from gr4vy.payment_methods import PaymentMethods
from gr4vy.payment_options import PaymentOptions
from gr4vy.payment_service_definitions import PaymentServiceDefinitions
from gr4vy.payment_services import PaymentServices
from gr4vy.payouts import Payouts
from gr4vy.refunds import Refunds
from gr4vy.transactions import Transactions
from gr4vy.types import OptionalNullable, UNSET
import httpx
from typing import Any, Callable, Dict, Optional, Union, cast
import weakref


class Gr4vy(BaseSDK):
    r"""Gr4vy: The Gr4vy API."""

    account_updater: AccountUpdater
    buyers: Buyers
    payment_methods: PaymentMethods
    gift_cards: GiftCards
    card_scheme_definitions: CardSchemeDefinitions
    digital_wallets: DigitalWallets
    transactions: Transactions
    refunds: Refunds
    payment_options: PaymentOptions
    payment_service_definitions: PaymentServiceDefinitions
    payment_services: PaymentServices
    audit_logs: AuditLogs
    checkout_sessions: CheckoutSessions
    merchant_accounts: MerchantAccounts
    payouts: Payouts

    def __init__(
        self,
        bearer_auth: Optional[Union[Optional[str], Callable[[], Optional[str]]]] = None,
        merchant_account_id: Optional[str] = None,
        id: Optional[str] = None,
        server: Optional[str] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param bearer_auth: The bearer_auth required for authentication
        :param merchant_account_id: Configures the merchant_account_id parameter for all supported operations
        :param id: Allows setting the id variable for url substitution
        :param server: The server by name to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        client_supplied = True
        if client is None:
            client = httpx.Client()
            client_supplied = False

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        async_client_supplied = True
        if async_client is None:
            async_client = httpx.AsyncClient()
            async_client_supplied = False

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Any = None
        if callable(bearer_auth):
            # pylint: disable=unnecessary-lambda-assignment
            security = lambda: models.Security(bearer_auth=bearer_auth())
        else:
            security = models.Security(bearer_auth=bearer_auth)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        server_defaults: Dict[str, Dict[str, str]] = {
            "production": {
                "id": id or "example",
            },
            "sandbox": {
                "id": id or "example",
            },
        }

        _globals = internal.Globals(
            merchant_account_id=utils.get_global_from_env(
                merchant_account_id, "GR4VY_MERCHANT_ACCOUNT_ID", str
            ),
        )

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                client_supplied=client_supplied,
                async_client=async_client,
                async_client_supplied=async_client_supplied,
                globals=_globals,
                security=security,
                server_url=server_url,
                server=server,
                server_defaults=server_defaults,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.client_supplied,
            self.sdk_configuration.async_client,
            self.sdk_configuration.async_client_supplied,
        )

        self._init_sdks()

    def _init_sdks(self):
        self.account_updater = AccountUpdater(self.sdk_configuration)
        self.buyers = Buyers(self.sdk_configuration)
        self.payment_methods = PaymentMethods(self.sdk_configuration)
        self.gift_cards = GiftCards(self.sdk_configuration)
        self.card_scheme_definitions = CardSchemeDefinitions(self.sdk_configuration)
        self.digital_wallets = DigitalWallets(self.sdk_configuration)
        self.transactions = Transactions(self.sdk_configuration)
        self.refunds = Refunds(self.sdk_configuration)
        self.payment_options = PaymentOptions(self.sdk_configuration)
        self.payment_service_definitions = PaymentServiceDefinitions(
            self.sdk_configuration
        )
        self.payment_services = PaymentServices(self.sdk_configuration)
        self.audit_logs = AuditLogs(self.sdk_configuration)
        self.checkout_sessions = CheckoutSessions(self.sdk_configuration)
        self.merchant_accounts = MerchantAccounts(self.sdk_configuration)
        self.payouts = Payouts(self.sdk_configuration)

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.client is not None
            and not self.sdk_configuration.client_supplied
        ):
            self.sdk_configuration.client.close()
        self.sdk_configuration.client = None

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.async_client is not None
            and not self.sdk_configuration.async_client_supplied
        ):
            await self.sdk_configuration.async_client.aclose()
        self.sdk_configuration.async_client = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from typing_extensions import TypedDict


class FieldTTypedDict(TypedDict):
    r"""A field used in a payment service"""

    key: str
    r"""The ID of the configured field."""
    value: str
    r"""The value of the configured field."""


class FieldT(BaseModel):
    r"""A field used in a payment service"""

    key: str
    r"""The ID of the configured field."""

    value: str
    r"""The value of the configured field."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .accountupdaterinquirysummary import (
    AccountUpdaterInquirySummary,
    AccountUpdaterInquirySummaryTypedDict,
)
from .accountupdaterjob import AccountUpdaterJob, AccountUpdaterJobTypedDict
from .accountupdaterjobcreate import (
    AccountUpdaterJobCreate,
    AccountUpdaterJobCreateTypedDict,
)
from .add_buyer_shipping_detailsop import (
    AddBuyerShippingDetailsGlobals,
    AddBuyerShippingDetailsGlobalsTypedDict,
    AddBuyerShippingDetailsRequest,
    AddBuyerShippingDetailsRequestTypedDict,
)
from .add_buyerop import (
    AddBuyerGlobals,
    AddBuyerGlobalsTypedDict,
    AddBuyerRequest,
    AddBuyerRequestTypedDict,
)
from .address import Address, AddressTypedDict
from .airline import Airline, AirlineTypedDict, TicketDeliveryMethod
from .airlineleg import AirlineLeg, AirlineLegTypedDict, RouteType
from .airlinepassenger import AgeGroup, AirlinePassenger, AirlinePassengerTypedDict
from .antifrauddecision import AntiFraudDecision
from .applepaypaymentmethodcreate import (
    ApplePayPaymentMethodCreate,
    ApplePayPaymentMethodCreateTypedDict,
)
from .applepaysessionrequest import (
    ApplePaySessionRequest,
    ApplePaySessionRequestTypedDict,
)
from .approvaltarget import ApprovalTarget
from .auditlogaction import AuditLogAction
from .auditlogentry import AuditLogEntry, AuditLogEntryTypedDict
from .auditlogentryresource import AuditLogEntryResource, AuditLogEntryResourceTypedDict
from .auditlogentryuser import AuditLogEntryUser, AuditLogEntryUserTypedDict
from .avsresponsecode import AVSResponseCode
from .billingdetails_input import BillingDetailsInput, BillingDetailsInputTypedDict
from .billingdetails_output import BillingDetailsOutput, BillingDetailsOutputTypedDict
from .browserinfo import BrowserInfo, BrowserInfoTypedDict, UserDevice
from .buyer import Buyer, BuyerTypedDict
from .buyercreate import BuyerCreate, BuyerCreateTypedDict
from .buyerupdate import BuyerUpdate, BuyerUpdateTypedDict
from .capture_transactionop import (
    CaptureTransactionGlobals,
    CaptureTransactionGlobalsTypedDict,
    CaptureTransactionRequest,
    CaptureTransactionRequestTypedDict,
)
from .cardpaymentmethodcreate import (
    CardPaymentMethodCreate,
    CardPaymentMethodCreateTypedDict,
)
from .cardscheme import CardScheme
from .cardschemedefinition import CardSchemeDefinition, CardSchemeDefinitionTypedDict
from .cardtype import CardType
from .cardwithurlpaymentmethodcreate import (
    CardWithURLPaymentMethodCreate,
    CardWithURLPaymentMethodCreateTypedDict,
)
from .cartitem import CartItem, CartItemTypedDict
from .checkoutcardconnectionoptions import (
    CheckoutCardConnectionOptions,
    CheckoutCardConnectionOptionsTypedDict,
)
from .checkoutsession import CheckoutSession, CheckoutSessionTypedDict
from .checkoutsessioncreate import CheckoutSessionCreate, CheckoutSessionCreateTypedDict
from .checkoutsessionpaymentmethod import (
    CheckoutSessionPaymentMethod,
    CheckoutSessionPaymentMethodTypedDict,
)
from .checkoutsessionpaymentmethodcreate import (
    CheckoutSessionPaymentMethodCreate,
    CheckoutSessionPaymentMethodCreateTypedDict,
)
from .checkoutsessionpaymentmethoddetails import (
    CheckoutSessionPaymentMethodDetails,
    CheckoutSessionPaymentMethodDetailsTypedDict,
)
from .checkoutsessionwithurlpaymentmethodcreate import (
    CheckoutSessionWithURLPaymentMethodCreate,
    CheckoutSessionWithURLPaymentMethodCreateTypedDict,
)
from .clicktopayfpanpaymentmethodcreate import (
    ClickToPayFPANPaymentMethodCreate,
    ClickToPayFPANPaymentMethodCreateTypedDict,
)
from .clicktopaypaymentmethodcreate import (
    ClickToPayPaymentMethodCreate,
    ClickToPayPaymentMethodCreateTypedDict,
)
from .clicktopaysession import ClickToPaySession, ClickToPaySessionTypedDict
from .clicktopaysessionrequest import (
    ClickToPaySessionRequest,
    ClickToPaySessionRequestTypedDict,
)
from .collection_auditlogentry_ import (
    CollectionAuditLogEntry,
    CollectionAuditLogEntryTypedDict,
)
from .collection_buyer_ import CollectionBuyer, CollectionBuyerTypedDict
from .collection_giftcard_ import CollectionGiftCard, CollectionGiftCardTypedDict
from .collection_merchantaccount_ import (
    CollectionMerchantAccount,
    CollectionMerchantAccountTypedDict,
)
from .collection_paymentmethod_ import (
    CollectionPaymentMethod,
    CollectionPaymentMethodTypedDict,
)
from .collection_paymentservice_ import (
    CollectionPaymentService,
    CollectionPaymentServiceTypedDict,
)
from .collection_paymentservicedefinition_ import (
    CollectionPaymentServiceDefinition,
    CollectionPaymentServiceDefinitionTypedDict,
)
from .collection_payoutsummary_ import (
    CollectionPayoutSummary,
    CollectionPayoutSummaryTypedDict,
)
from .collection_refund_ import CollectionRefund, CollectionRefundTypedDict
from .collection_transactionsummary_ import (
    CollectionTransactionSummary,
    CollectionTransactionSummaryTypedDict,
)
from .collectionnocursor_cardschemedefinition_ import (
    CollectionNoCursorCardSchemeDefinition,
    CollectionNoCursorCardSchemeDefinitionTypedDict,
)
from .collectionnocursor_digitalwallet_ import (
    CollectionNoCursorDigitalWallet,
    CollectionNoCursorDigitalWalletTypedDict,
)
from .collectionnocursor_giftcardsummary_ import (
    CollectionNoCursorGiftCardSummary,
    CollectionNoCursorGiftCardSummaryTypedDict,
)
from .collectionnocursor_networktoken_ import (
    CollectionNoCursorNetworkToken,
    CollectionNoCursorNetworkTokenTypedDict,
)
from .collectionnocursor_paymentmethodsummary_ import (
    CollectionNoCursorPaymentMethodSummary,
    CollectionNoCursorPaymentMethodSummaryTypedDict,
)
from .collectionnocursor_paymentoption_ import (
    CollectionNoCursorPaymentOption,
    CollectionNoCursorPaymentOptionTypedDict,
)
from .collectionnocursor_paymentservicetoken_ import (
    CollectionNoCursorPaymentServiceToken,
    CollectionNoCursorPaymentServiceTokenTypedDict,
)
from .collectionnocursor_refund_ import (
    CollectionNoCursorRefund,
    CollectionNoCursorRefundTypedDict,
)
from .collectionnocursor_shippingdetails_ import (
    CollectionNoCursorShippingDetails,
    CollectionNoCursorShippingDetailsTypedDict,
)
from .configure_digital_walletop import (
    ConfigureDigitalWalletGlobals,
    ConfigureDigitalWalletGlobalsTypedDict,
    ConfigureDigitalWalletRequest,
    ConfigureDigitalWalletRequestTypedDict,
)
from .connectionoptions import ConnectionOptions, ConnectionOptionsTypedDict
from .create_account_updater_jobop import (
    CreateAccountUpdaterJobGlobals,
    CreateAccountUpdaterJobGlobalsTypedDict,
    CreateAccountUpdaterJobRequest,
    CreateAccountUpdaterJobRequestTypedDict,
)
from .create_apple_pay_digital_wallet_sessionop import (
    CreateApplePayDigitalWalletSessionGlobals,
    CreateApplePayDigitalWalletSessionGlobalsTypedDict,
    CreateApplePayDigitalWalletSessionRequest,
    CreateApplePayDigitalWalletSessionRequestTypedDict,
)
from .create_checkout_sessionop import (
    CreateCheckoutSessionGlobals,
    CreateCheckoutSessionGlobalsTypedDict,
    CreateCheckoutSessionRequest,
    CreateCheckoutSessionRequestTypedDict,
)
from .create_full_transaction_refundop import (
    CreateFullTransactionRefundGlobals,
    CreateFullTransactionRefundGlobalsTypedDict,
    CreateFullTransactionRefundRequest,
    CreateFullTransactionRefundRequestTypedDict,
)
from .create_gift_cardop import (
    CreateGiftCardGlobals,
    CreateGiftCardGlobalsTypedDict,
    CreateGiftCardRequest,
    CreateGiftCardRequestTypedDict,
)
from .create_google_pay_digital_wallet_sessionop import (
    CreateGooglePayDigitalWalletSessionGlobals,
    CreateGooglePayDigitalWalletSessionGlobalsTypedDict,
    CreateGooglePayDigitalWalletSessionRequest,
    CreateGooglePayDigitalWalletSessionRequestTypedDict,
)
from .create_merchant_accountop import (
    CreateMerchantAccountRequest,
    CreateMerchantAccountRequestTypedDict,
)
from .create_payment_method_network_token_cryptogramop import (
    CreatePaymentMethodNetworkTokenCryptogramGlobals,
    CreatePaymentMethodNetworkTokenCryptogramGlobalsTypedDict,
    CreatePaymentMethodNetworkTokenCryptogramRequest,
    CreatePaymentMethodNetworkTokenCryptogramRequestTypedDict,
)
from .create_payment_method_network_tokenop import (
    CreatePaymentMethodNetworkTokenGlobals,
    CreatePaymentMethodNetworkTokenGlobalsTypedDict,
    CreatePaymentMethodNetworkTokenRequest,
    CreatePaymentMethodNetworkTokenRequestTypedDict,
)
from .create_payment_method_payment_service_tokenop import (
    CreatePaymentMethodPaymentServiceTokenGlobals,
    CreatePaymentMethodPaymentServiceTokenGlobalsTypedDict,
    CreatePaymentMethodPaymentServiceTokenRequest,
    CreatePaymentMethodPaymentServiceTokenRequestTypedDict,
)
from .create_payment_methodop import (
    Body,
    BodyTypedDict,
    CreatePaymentMethodGlobals,
    CreatePaymentMethodGlobalsTypedDict,
    CreatePaymentMethodRequest,
    CreatePaymentMethodRequestTypedDict,
)
from .create_payment_service_definition_sessionop import (
    CreatePaymentServiceDefinitionSessionRequest,
    CreatePaymentServiceDefinitionSessionRequestTypedDict,
)
from .create_payment_service_sessionop import (
    CreatePaymentServiceSessionGlobals,
    CreatePaymentServiceSessionGlobalsTypedDict,
    CreatePaymentServiceSessionRequest,
    CreatePaymentServiceSessionRequestTypedDict,
)
from .create_payment_serviceop import (
    CreatePaymentServiceGlobals,
    CreatePaymentServiceGlobalsTypedDict,
    CreatePaymentServiceRequest,
    CreatePaymentServiceRequestTypedDict,
)
from .create_payoutop import (
    CreatePayoutGlobals,
    CreatePayoutGlobalsTypedDict,
    CreatePayoutRequest,
    CreatePayoutRequestTypedDict,
)
from .create_transaction_refundop import (
    CreateTransactionRefundGlobals,
    CreateTransactionRefundGlobalsTypedDict,
    CreateTransactionRefundRequest,
    CreateTransactionRefundRequestTypedDict,
)
from .create_transactionop import (
    CreateTransactionGlobals,
    CreateTransactionGlobalsTypedDict,
    CreateTransactionRequest,
    CreateTransactionRequestTypedDict,
)
from .createsession import CreateSession, CreateSessionTypedDict
from .createsessionstatus import CreateSessionStatus
from .creator import Creator, CreatorTypedDict
from .cryptogram import Cryptogram, CryptogramTypedDict
from .cryptogramcreate import CryptogramCreate, CryptogramCreateTypedDict
from .cvvresponsecode import CVVResponseCode
from .definitionfield import DefinitionField, DefinitionFieldTypedDict
from .definitionfieldformat import DefinitionFieldFormat
from .delete_buyer_shipping_detailsop import (
    DeleteBuyerShippingDetailsGlobals,
    DeleteBuyerShippingDetailsGlobalsTypedDict,
    DeleteBuyerShippingDetailsRequest,
    DeleteBuyerShippingDetailsRequestTypedDict,
)
from .delete_buyerop import (
    DeleteBuyerGlobals,
    DeleteBuyerGlobalsTypedDict,
    DeleteBuyerRequest,
    DeleteBuyerRequestTypedDict,
)
from .delete_checkout_sessionop import (
    DeleteCheckoutSessionGlobals,
    DeleteCheckoutSessionGlobalsTypedDict,
    DeleteCheckoutSessionRequest,
    DeleteCheckoutSessionRequestTypedDict,
)
from .delete_digital_walletop import (
    DeleteDigitalWalletGlobals,
    DeleteDigitalWalletGlobalsTypedDict,
    DeleteDigitalWalletRequest,
    DeleteDigitalWalletRequestTypedDict,
)
from .delete_gift_cardop import (
    DeleteGiftCardGlobals,
    DeleteGiftCardGlobalsTypedDict,
    DeleteGiftCardRequest,
    DeleteGiftCardRequestTypedDict,
)
from .delete_payment_method_network_tokenop import (
    DeletePaymentMethodNetworkTokenGlobals,
    DeletePaymentMethodNetworkTokenGlobalsTypedDict,
    DeletePaymentMethodNetworkTokenRequest,
    DeletePaymentMethodNetworkTokenRequestTypedDict,
)
from .delete_payment_method_payment_service_tokenop import (
    DeletePaymentMethodPaymentServiceTokenGlobals,
    DeletePaymentMethodPaymentServiceTokenGlobalsTypedDict,
    DeletePaymentMethodPaymentServiceTokenRequest,
    DeletePaymentMethodPaymentServiceTokenRequestTypedDict,
)
from .delete_payment_methodop import (
    DeletePaymentMethodGlobals,
    DeletePaymentMethodGlobalsTypedDict,
    DeletePaymentMethodRequest,
    DeletePaymentMethodRequestTypedDict,
)
from .delete_payment_serviceop import (
    DeletePaymentServiceGlobals,
    DeletePaymentServiceGlobalsTypedDict,
    DeletePaymentServiceRequest,
    DeletePaymentServiceRequestTypedDict,
)
from .digitalwallet import DigitalWallet, DigitalWalletTypedDict
from .digitalwalletcreate import DigitalWalletCreate, DigitalWalletCreateTypedDict
from .digitalwalletdomain import DigitalWalletDomain, DigitalWalletDomainTypedDict
from .digitalwalletprovider import DigitalWalletProvider
from .digitalwalletupdate import DigitalWalletUpdate, DigitalWalletUpdateTypedDict
from .errordetail import ErrorDetail, ErrorDetailTypedDict
from .errorlocation import ErrorLocation
from .field import FieldT, FieldTTypedDict
from .get_buyer_shipping_detailsop import (
    GetBuyerShippingDetailsGlobals,
    GetBuyerShippingDetailsGlobalsTypedDict,
    GetBuyerShippingDetailsRequest,
    GetBuyerShippingDetailsRequestTypedDict,
)
from .get_buyerop import (
    GetBuyerGlobals,
    GetBuyerGlobalsTypedDict,
    GetBuyerRequest,
    GetBuyerRequestTypedDict,
)
from .get_checkout_sessionop import (
    GetCheckoutSessionGlobals,
    GetCheckoutSessionGlobalsTypedDict,
    GetCheckoutSessionRequest,
    GetCheckoutSessionRequestTypedDict,
)
from .get_digital_walletop import (
    GetDigitalWalletGlobals,
    GetDigitalWalletGlobalsTypedDict,
    GetDigitalWalletRequest,
    GetDigitalWalletRequestTypedDict,
)
from .get_gift_cardop import (
    GetGiftCardGlobals,
    GetGiftCardGlobalsTypedDict,
    GetGiftCardRequest,
    GetGiftCardRequestTypedDict,
)
from .get_merchant_accountop import (
    GetMerchantAccountRequest,
    GetMerchantAccountRequestTypedDict,
)
from .get_payment_methodop import (
    GetPaymentMethodGlobals,
    GetPaymentMethodGlobalsTypedDict,
    GetPaymentMethodRequest,
    GetPaymentMethodRequestTypedDict,
)
from .get_payment_service_definitionop import (
    GetPaymentServiceDefinitionRequest,
    GetPaymentServiceDefinitionRequestTypedDict,
)
from .get_payment_serviceop import (
    GetPaymentServiceGlobals,
    GetPaymentServiceGlobalsTypedDict,
    GetPaymentServiceRequest,
    GetPaymentServiceRequestTypedDict,
)
from .get_payoutop import (
    GetPayoutGlobals,
    GetPayoutGlobalsTypedDict,
    GetPayoutRequest,
    GetPayoutRequestTypedDict,
)
from .get_refundop import (
    GetRefundGlobals,
    GetRefundGlobalsTypedDict,
    GetRefundRequest,
    GetRefundRequestTypedDict,
)
from .get_transaction_refundop import (
    GetTransactionRefundGlobals,
    GetTransactionRefundGlobalsTypedDict,
    GetTransactionRefundRequest,
    GetTransactionRefundRequestTypedDict,
)
from .get_transaction_summaryop import (
    GetTransactionSummaryGlobals,
    GetTransactionSummaryGlobalsTypedDict,
    GetTransactionSummaryRequest,
    GetTransactionSummaryRequestTypedDict,
)
from .get_transactionop import (
    GetTransactionGlobals,
    GetTransactionGlobalsTypedDict,
    GetTransactionRequest,
    GetTransactionRequestTypedDict,
)
from .giftcard import GiftCard, GiftCardTypedDict
from .giftcardbalancerequest import (
    GiftCardBalanceRequest,
    GiftCardBalanceRequestTypedDict,
    Item,
    ItemTypedDict,
)
from .giftcardcreate import GiftCardCreate, GiftCardCreateTypedDict
from .giftcarderrorcode import GiftCardErrorCode
from .giftcardredemption import GiftCardRedemption, GiftCardRedemptionTypedDict
from .giftcardredemptionstatus import GiftCardRedemptionStatus
from .giftcardrequest import GiftCardRequest, GiftCardRequestTypedDict
from .giftcardservice import GiftCardService, GiftCardServiceTypedDict
from .giftcardserviceprovider import GiftCardServiceProvider
from .giftcardstoredrequest import GiftCardStoredRequest, GiftCardStoredRequestTypedDict
from .giftcardsummary import GiftCardSummary, GiftCardSummaryTypedDict
from .giftcardtokentransactioncreate import (
    GiftCardTokenTransactionCreate,
    GiftCardTokenTransactionCreateTypedDict,
)
from .giftcardtransactioncreate import (
    GiftCardTransactionCreate,
    GiftCardTransactionCreateTypedDict,
)
from .googlepayassurancedetails import (
    GooglePayAssuranceDetails,
    GooglePayAssuranceDetailsTypedDict,
)
from .googlepayfpanpaymentmethodcreate import (
    GooglePayFPANPaymentMethodCreate,
    GooglePayFPANPaymentMethodCreateTypedDict,
)
from .googlepaypaymentmethodcreate import (
    GooglePayPaymentMethodCreate,
    GooglePayPaymentMethodCreateTypedDict,
    Token,
    TokenTypedDict,
)
from .googlepaypaymentoptioncontext import (
    GooglePayPaymentOptionContext,
    GooglePayPaymentOptionContextTypedDict,
)
from .googlepaysession import GooglePaySession, GooglePaySessionTypedDict
from .googlepaysessionrequest import (
    GooglePaySessionRequest,
    GooglePaySessionRequestTypedDict,
)
from .guestbuyer_input import GuestBuyerInput, GuestBuyerInputTypedDict
from .guestbuyer_output import GuestBuyerOutput, GuestBuyerOutputTypedDict
from .instrumenttype import InstrumentType
from .list_audit_logsop import (
    ListAuditLogsGlobals,
    ListAuditLogsGlobalsTypedDict,
    ListAuditLogsRequest,
    ListAuditLogsRequestTypedDict,
    ListAuditLogsResponse,
    ListAuditLogsResponseTypedDict,
)
from .list_buyer_gift_cardsop import (
    ListBuyerGiftCardsGlobals,
    ListBuyerGiftCardsGlobalsTypedDict,
    ListBuyerGiftCardsRequest,
    ListBuyerGiftCardsRequestTypedDict,
)
from .list_buyer_payment_methodsop import (
    ListBuyerPaymentMethodsGlobals,
    ListBuyerPaymentMethodsGlobalsTypedDict,
    ListBuyerPaymentMethodsRequest,
    ListBuyerPaymentMethodsRequestTypedDict,
    OrderBy,
)
from .list_buyer_shipping_detailsop import (
    ListBuyerShippingDetailsGlobals,
    ListBuyerShippingDetailsGlobalsTypedDict,
    ListBuyerShippingDetailsRequest,
    ListBuyerShippingDetailsRequestTypedDict,
)
from .list_buyersop import (
    ListBuyersGlobals,
    ListBuyersGlobalsTypedDict,
    ListBuyersRequest,
    ListBuyersRequestTypedDict,
    ListBuyersResponse,
    ListBuyersResponseTypedDict,
)
from .list_card_scheme_definitionsop import (
    ListCardSchemeDefinitionsGlobals,
    ListCardSchemeDefinitionsGlobalsTypedDict,
    ListCardSchemeDefinitionsRequest,
    ListCardSchemeDefinitionsRequestTypedDict,
)
from .list_digital_walletsop import (
    ListDigitalWalletsGlobals,
    ListDigitalWalletsGlobalsTypedDict,
    ListDigitalWalletsRequest,
    ListDigitalWalletsRequestTypedDict,
)
from .list_gift_card_balancesop import (
    ListGiftCardBalancesGlobals,
    ListGiftCardBalancesGlobalsTypedDict,
    ListGiftCardBalancesRequest,
    ListGiftCardBalancesRequestTypedDict,
)
from .list_gift_cardsop import (
    ListGiftCardsGlobals,
    ListGiftCardsGlobalsTypedDict,
    ListGiftCardsRequest,
    ListGiftCardsRequestTypedDict,
    ListGiftCardsResponse,
    ListGiftCardsResponseTypedDict,
)
from .list_merchant_accountsop import (
    ListMerchantAccountsRequest,
    ListMerchantAccountsRequestTypedDict,
    ListMerchantAccountsResponse,
    ListMerchantAccountsResponseTypedDict,
)
from .list_payment_method_network_tokensop import (
    ListPaymentMethodNetworkTokensGlobals,
    ListPaymentMethodNetworkTokensGlobalsTypedDict,
    ListPaymentMethodNetworkTokensRequest,
    ListPaymentMethodNetworkTokensRequestTypedDict,
)
from .list_payment_method_payment_service_tokensop import (
    ListPaymentMethodPaymentServiceTokensGlobals,
    ListPaymentMethodPaymentServiceTokensGlobalsTypedDict,
    ListPaymentMethodPaymentServiceTokensRequest,
    ListPaymentMethodPaymentServiceTokensRequestTypedDict,
)
from .list_payment_methodsop import (
    ListPaymentMethodsGlobals,
    ListPaymentMethodsGlobalsTypedDict,
    ListPaymentMethodsRequest,
    ListPaymentMethodsRequestTypedDict,
    ListPaymentMethodsResponse,
    ListPaymentMethodsResponseTypedDict,
)
from .list_payment_optionsop import (
    ListPaymentOptionsGlobals,
    ListPaymentOptionsGlobalsTypedDict,
    ListPaymentOptionsRequest,
    ListPaymentOptionsRequestTypedDict,
)
from .list_payment_service_definitionsop import (
    ListPaymentServiceDefinitionsRequest,
    ListPaymentServiceDefinitionsRequestTypedDict,
    ListPaymentServiceDefinitionsResponse,
    ListPaymentServiceDefinitionsResponseTypedDict,
)
from .list_payment_servicesop import (
    ListPaymentServicesGlobals,
    ListPaymentServicesGlobalsTypedDict,
    ListPaymentServicesRequest,
    ListPaymentServicesRequestTypedDict,
    ListPaymentServicesResponse,
    ListPaymentServicesResponseTypedDict,
)
from .list_payoutsop import (
    ListPayoutsGlobals,
    ListPayoutsGlobalsTypedDict,
    ListPayoutsRequest,
    ListPayoutsRequestTypedDict,
    ListPayoutsResponse,
    ListPayoutsResponseTypedDict,
)
from .list_transaction_refundsop import (
    ListTransactionRefundsGlobals,
    ListTransactionRefundsGlobalsTypedDict,
    ListTransactionRefundsRequest,
    ListTransactionRefundsRequestTypedDict,
)
from .list_transactionsop import (
    ListTransactionsGlobals,
    ListTransactionsGlobalsTypedDict,
    ListTransactionsRequest,
    ListTransactionsRequestTypedDict,
    ListTransactionsResponse,
    ListTransactionsResponseTypedDict,
)
from .merchantaccount import MerchantAccount, MerchantAccountTypedDict
from .merchantaccountcreate import MerchantAccountCreate, MerchantAccountCreateTypedDict
from .merchantaccountupdate import MerchantAccountUpdate, MerchantAccountUpdateTypedDict
from .merchantprofilescheme import MerchantProfileScheme, MerchantProfileSchemeTypedDict
from .merchantprofileschemesummary import (
    MerchantProfileSchemeSummary,
    MerchantProfileSchemeSummaryTypedDict,
)
from .method import Method
from .mode import Mode
from .networktoken import NetworkToken, NetworkTokenTypedDict
from .networktokencreate import NetworkTokenCreate, NetworkTokenCreateTypedDict
from .networktokenpaymentmethodcreate import (
    CardSource,
    NetworkTokenPaymentMethodCreate,
    NetworkTokenPaymentMethodCreateTypedDict,
)
from .networktokenstatus import NetworkTokenStatus
from .paymentmethod import PaymentMethod, PaymentMethodTypedDict
from .paymentmethodcard import PaymentMethodCard, PaymentMethodCardTypedDict
from .paymentmethoddetailscard import (
    PaymentMethodDetailsCard,
    PaymentMethodDetailsCardTypedDict,
)
from .paymentmethodstatus import PaymentMethodStatus
from .paymentmethodstoredcard import (
    PaymentMethodStoredCard,
    PaymentMethodStoredCardTypedDict,
)
from .paymentmethodsummary import PaymentMethodSummary, PaymentMethodSummaryTypedDict
from .paymentoption import (
    Context,
    ContextTypedDict,
    PaymentOption,
    PaymentOptionTypedDict,
)
from .paymentoptioncontext import (
    PaymentOptionContext,
    PaymentOptionContextTypedDict,
    RequiredFields1,
    RequiredFields1TypedDict,
    RequiredFields2,
    RequiredFields2TypedDict,
)
from .paymentoptioncontextapprovalui import (
    PaymentOptionContextApprovalUI,
    PaymentOptionContextApprovalUITypedDict,
)
from .paymentoptionrequest import PaymentOptionRequest, PaymentOptionRequestTypedDict
from .paymentservice import PaymentService, PaymentServiceTypedDict
from .paymentserviceconfiguration import (
    PaymentServiceConfiguration,
    PaymentServiceConfigurationTypedDict,
)
from .paymentservicecreate import PaymentServiceCreate, PaymentServiceCreateTypedDict
from .paymentservicedefinition import (
    PaymentServiceDefinition,
    PaymentServiceDefinitionTypedDict,
)
from .paymentservicestatus import PaymentServiceStatus
from .paymentservicetoken import PaymentServiceToken, PaymentServiceTokenTypedDict
from .paymentservicetokencreate import (
    PaymentServiceTokenCreate,
    PaymentServiceTokenCreateTypedDict,
)
from .paymentserviceupdate import PaymentServiceUpdate, PaymentServiceUpdateTypedDict
from .payoutcategory import PayoutCategory
from .payoutcreate import (
    PayoutCreate,
    PayoutCreatePaymentMethod,
    PayoutCreatePaymentMethodTypedDict,
    PayoutCreateTypedDict,
)
from .payoutmerchant import PayoutMerchant, PayoutMerchantTypedDict
from .payoutmerchantsummary import PayoutMerchantSummary, PayoutMerchantSummaryTypedDict
from .payoutpaymentservice import PayoutPaymentService, PayoutPaymentServiceTypedDict
from .payoutstatus import PayoutStatus
from .payoutsummary import PayoutSummary, PayoutSummaryTypedDict
from .producttype import ProductType
from .recipient import Recipient, RecipientTypedDict
from .redirectpaymentmethodcreate import (
    RedirectPaymentMethodCreate,
    RedirectPaymentMethodCreateMethod,
    RedirectPaymentMethodCreateTypedDict,
)
from .refund import Refund, RefundTypedDict
from .refundstatus import RefundStatus
from .refundtargettype import RefundTargetType
from .register_digital_wallet_domainop import (
    RegisterDigitalWalletDomainGlobals,
    RegisterDigitalWalletDomainGlobalsTypedDict,
    RegisterDigitalWalletDomainRequest,
    RegisterDigitalWalletDomainRequestTypedDict,
)
from .requiredcheckoutfields import (
    RequiredCheckoutFields,
    RequiredCheckoutFieldsTypedDict,
)
from .resume_payment_method_network_tokenop import (
    ResumePaymentMethodNetworkTokenGlobals,
    ResumePaymentMethodNetworkTokenGlobalsTypedDict,
    ResumePaymentMethodNetworkTokenRequest,
    ResumePaymentMethodNetworkTokenRequestTypedDict,
)
from .security import Security, SecurityTypedDict
from .shippingdetails import ShippingDetails, ShippingDetailsTypedDict
from .shippingdetailscreate import ShippingDetailsCreate, ShippingDetailsCreateTypedDict
from .shippingdetailsupdate import ShippingDetailsUpdate, ShippingDetailsUpdateTypedDict
from .statementdescriptor import StatementDescriptor, StatementDescriptorTypedDict
from .suspend_payment_method_network_tokenop import (
    SuspendPaymentMethodNetworkTokenGlobals,
    SuspendPaymentMethodNetworkTokenGlobalsTypedDict,
    SuspendPaymentMethodNetworkTokenRequest,
    SuspendPaymentMethodNetworkTokenRequestTypedDict,
)
from .sync_transactionop import (
    SyncTransactionGlobals,
    SyncTransactionGlobalsTypedDict,
    SyncTransactionRequest,
    SyncTransactionRequestTypedDict,
)
from .taxid import TaxID, TaxIDTypedDict
from .taxidkind import TaxIDKind
from .threedsecuredatav1 import ThreeDSecureDataV1, ThreeDSecureDataV1TypedDict
from .threedsecuredatav2 import ThreeDSecureDataV2, ThreeDSecureDataV2TypedDict
from .threedsecureerror import ThreeDSecureError, ThreeDSecureErrorTypedDict
from .threedsecuremethod import ThreeDSecureMethod
from .threedsecurestatus import ThreeDSecureStatus
from .threedsecurev2 import ThreeDSecureV2, ThreeDSecureV2TypedDict
from .tokenpaymentmethodcreate import (
    TokenPaymentMethodCreate,
    TokenPaymentMethodCreateTypedDict,
)
from .transaction import Transaction, TransactionTypedDict
from .transactionbuyer import TransactionBuyer, TransactionBuyerTypedDict
from .transactioncapture import TransactionCapture, TransactionCaptureTypedDict
from .transactioncreate import (
    GiftCardUnion,
    GiftCardUnionTypedDict,
    ThreeDSecureData,
    ThreeDSecureDataTypedDict,
    TransactionCreate,
    TransactionCreatePaymentMethod,
    TransactionCreatePaymentMethodTypedDict,
    TransactionCreateTypedDict,
)
from .transactiongiftcard import TransactionGiftCard, TransactionGiftCardTypedDict
from .transactionintent import TransactionIntent
from .transactionintentoutcome import TransactionIntentOutcome
from .transactionpaymentmethod import (
    TransactionPaymentMethod,
    TransactionPaymentMethodTypedDict,
)
from .transactionpaymentservice import (
    TransactionPaymentService,
    TransactionPaymentServiceTypedDict,
)
from .transactionpaymentsource import TransactionPaymentSource
from .transactionrefundallcreate import (
    TransactionRefundAllCreate,
    TransactionRefundAllCreateTypedDict,
)
from .transactionrefundcreate import (
    TransactionRefundCreate,
    TransactionRefundCreateTypedDict,
)
from .transactionstatus import TransactionStatus
from .transactionstatussummary import (
    TransactionStatusSummary,
    TransactionStatusSummaryTypedDict,
)
from .transactionsummary import TransactionSummary, TransactionSummaryTypedDict
from .transactionthreedsecuresummary import (
    ResponseData,
    ResponseDataTypedDict,
    TransactionThreeDSecureSummary,
    TransactionThreeDSecureSummaryTypedDict,
)
from .unregister_digital_wallet_domainop import (
    UnregisterDigitalWalletDomainGlobals,
    UnregisterDigitalWalletDomainGlobalsTypedDict,
    UnregisterDigitalWalletDomainRequest,
    UnregisterDigitalWalletDomainRequestTypedDict,
)
from .update_buyer_shipping_detailsop import (
    UpdateBuyerShippingDetailsGlobals,
    UpdateBuyerShippingDetailsGlobalsTypedDict,
    UpdateBuyerShippingDetailsRequest,
    UpdateBuyerShippingDetailsRequestTypedDict,
)
from .update_buyerop import (
    UpdateBuyerGlobals,
    UpdateBuyerGlobalsTypedDict,
    UpdateBuyerRequest,
    UpdateBuyerRequestTypedDict,
)
from .update_checkout_sessionop import (
    UpdateCheckoutSessionGlobals,
    UpdateCheckoutSessionGlobalsTypedDict,
    UpdateCheckoutSessionRequest,
    UpdateCheckoutSessionRequestTypedDict,
)
from .update_digital_walletop import (
    UpdateDigitalWalletGlobals,
    UpdateDigitalWalletGlobalsTypedDict,
    UpdateDigitalWalletRequest,
    UpdateDigitalWalletRequestTypedDict,
)
from .update_merchant_accountop import (
    UpdateMerchantAccountRequest,
    UpdateMerchantAccountRequestTypedDict,
)
from .update_payment_serviceop import (
    UpdatePaymentServiceGlobals,
    UpdatePaymentServiceGlobalsTypedDict,
    UpdatePaymentServiceRequest,
    UpdatePaymentServiceRequestTypedDict,
)
from .userstatus import UserStatus
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .verify_payment_service_credentialsop import (
    VerifyPaymentServiceCredentialsGlobals,
    VerifyPaymentServiceCredentialsGlobalsTypedDict,
    VerifyPaymentServiceCredentialsRequest,
    VerifyPaymentServiceCredentialsRequestTypedDict,
)
from .verifycredentials import VerifyCredentials, VerifyCredentialsTypedDict
from .void_transactionop import (
    VoidTransactionGlobals,
    VoidTransactionGlobalsTypedDict,
    VoidTransactionRequest,
    VoidTransactionRequestTypedDict,
)
from .voidablefield import VoidableField, VoidableFieldTypedDict
from .walletpaymentoptioncontext import (
    WalletPaymentOptionContext,
    WalletPaymentOptionContextTypedDict,
)


__all__ = [
    "AVSResponseCode",
    "AccountUpdaterInquirySummary",
    "AccountUpdaterInquirySummaryTypedDict",
    "AccountUpdaterJob",
    "AccountUpdaterJobCreate",
    "AccountUpdaterJobCreateTypedDict",
    "AccountUpdaterJobTypedDict",
    "AddBuyerGlobals",
    "AddBuyerGlobalsTypedDict",
    "AddBuyerRequest",
    "AddBuyerRequestTypedDict",
    "AddBuyerShippingDetailsGlobals",
    "AddBuyerShippingDetailsGlobalsTypedDict",
    "AddBuyerShippingDetailsRequest",
    "AddBuyerShippingDetailsRequestTypedDict",
    "Address",
    "AddressTypedDict",
    "AgeGroup",
    "Airline",
    "AirlineLeg",
    "AirlineLegTypedDict",
    "AirlinePassenger",
    "AirlinePassengerTypedDict",
    "AirlineTypedDict",
    "AntiFraudDecision",
    "ApplePayPaymentMethodCreate",
    "ApplePayPaymentMethodCreateTypedDict",
    "ApplePaySessionRequest",
    "ApplePaySessionRequestTypedDict",
    "ApprovalTarget",
    "AuditLogAction",
    "AuditLogEntry",
    "AuditLogEntryResource",
    "AuditLogEntryResourceTypedDict",
    "AuditLogEntryTypedDict",
    "AuditLogEntryUser",
    "AuditLogEntryUserTypedDict",
    "BillingDetailsInput",
    "BillingDetailsInputTypedDict",
    "BillingDetailsOutput",
    "BillingDetailsOutputTypedDict",
    "Body",
    "BodyTypedDict",
    "BrowserInfo",
    "BrowserInfoTypedDict",
    "Buyer",
    "BuyerCreate",
    "BuyerCreateTypedDict",
    "BuyerTypedDict",
    "BuyerUpdate",
    "BuyerUpdateTypedDict",
    "CVVResponseCode",
    "CaptureTransactionGlobals",
    "CaptureTransactionGlobalsTypedDict",
    "CaptureTransactionRequest",
    "CaptureTransactionRequestTypedDict",
    "CardPaymentMethodCreate",
    "CardPaymentMethodCreateTypedDict",
    "CardScheme",
    "CardSchemeDefinition",
    "CardSchemeDefinitionTypedDict",
    "CardSource",
    "CardType",
    "CardWithURLPaymentMethodCreate",
    "CardWithURLPaymentMethodCreateTypedDict",
    "CartItem",
    "CartItemTypedDict",
    "CheckoutCardConnectionOptions",
    "CheckoutCardConnectionOptionsTypedDict",
    "CheckoutSession",
    "CheckoutSessionCreate",
    "CheckoutSessionCreateTypedDict",
    "CheckoutSessionPaymentMethod",
    "CheckoutSessionPaymentMethodCreate",
    "CheckoutSessionPaymentMethodCreateTypedDict",
    "CheckoutSessionPaymentMethodDetails",
    "CheckoutSessionPaymentMethodDetailsTypedDict",
    "CheckoutSessionPaymentMethodTypedDict",
    "CheckoutSessionTypedDict",
    "CheckoutSessionWithURLPaymentMethodCreate",
    "CheckoutSessionWithURLPaymentMethodCreateTypedDict",
    "ClickToPayFPANPaymentMethodCreate",
    "ClickToPayFPANPaymentMethodCreateTypedDict",
    "ClickToPayPaymentMethodCreate",
    "ClickToPayPaymentMethodCreateTypedDict",
    "ClickToPaySession",
    "ClickToPaySessionRequest",
    "ClickToPaySessionRequestTypedDict",
    "ClickToPaySessionTypedDict",
    "CollectionAuditLogEntry",
    "CollectionAuditLogEntryTypedDict",
    "CollectionBuyer",
    "CollectionBuyerTypedDict",
    "CollectionGiftCard",
    "CollectionGiftCardTypedDict",
    "CollectionMerchantAccount",
    "CollectionMerchantAccountTypedDict",
    "CollectionNoCursorCardSchemeDefinition",
    "CollectionNoCursorCardSchemeDefinitionTypedDict",
    "CollectionNoCursorDigitalWallet",
    "CollectionNoCursorDigitalWalletTypedDict",
    "CollectionNoCursorGiftCardSummary",
    "CollectionNoCursorGiftCardSummaryTypedDict",
    "CollectionNoCursorNetworkToken",
    "CollectionNoCursorNetworkTokenTypedDict",
    "CollectionNoCursorPaymentMethodSummary",
    "CollectionNoCursorPaymentMethodSummaryTypedDict",
    "CollectionNoCursorPaymentOption",
    "CollectionNoCursorPaymentOptionTypedDict",
    "CollectionNoCursorPaymentServiceToken",
    "CollectionNoCursorPaymentServiceTokenTypedDict",
    "CollectionNoCursorRefund",
    "CollectionNoCursorRefundTypedDict",
    "CollectionNoCursorShippingDetails",
    "CollectionNoCursorShippingDetailsTypedDict",
    "CollectionPaymentMethod",
    "CollectionPaymentMethodTypedDict",
    "CollectionPaymentService",
    "CollectionPaymentServiceDefinition",
    "CollectionPaymentServiceDefinitionTypedDict",
    "CollectionPaymentServiceTypedDict",
    "CollectionPayoutSummary",
    "CollectionPayoutSummaryTypedDict",
    "CollectionRefund",
    "CollectionRefundTypedDict",
    "CollectionTransactionSummary",
    "CollectionTransactionSummaryTypedDict",
    "ConfigureDigitalWalletGlobals",
    "ConfigureDigitalWalletGlobalsTypedDict",
    "ConfigureDigitalWalletRequest",
    "ConfigureDigitalWalletRequestTypedDict",
    "ConnectionOptions",
    "ConnectionOptionsTypedDict",
    "Context",
    "ContextTypedDict",
    "CreateAccountUpdaterJobGlobals",
    "CreateAccountUpdaterJobGlobalsTypedDict",
    "CreateAccountUpdaterJobRequest",
    "CreateAccountUpdaterJobRequestTypedDict",
    "CreateApplePayDigitalWalletSessionGlobals",
    "CreateApplePayDigitalWalletSessionGlobalsTypedDict",
    "CreateApplePayDigitalWalletSessionRequest",
    "CreateApplePayDigitalWalletSessionRequestTypedDict",
    "CreateCheckoutSessionGlobals",
    "CreateCheckoutSessionGlobalsTypedDict",
    "CreateCheckoutSessionRequest",
    "CreateCheckoutSessionRequestTypedDict",
    "CreateFullTransactionRefundGlobals",
    "CreateFullTransactionRefundGlobalsTypedDict",
    "CreateFullTransactionRefundRequest",
    "CreateFullTransactionRefundRequestTypedDict",
    "CreateGiftCardGlobals",
    "CreateGiftCardGlobalsTypedDict",
    "CreateGiftCardRequest",
    "CreateGiftCardRequestTypedDict",
    "CreateGooglePayDigitalWalletSessionGlobals",
    "CreateGooglePayDigitalWalletSessionGlobalsTypedDict",
    "CreateGooglePayDigitalWalletSessionRequest",
    "CreateGooglePayDigitalWalletSessionRequestTypedDict",
    "CreateMerchantAccountRequest",
    "CreateMerchantAccountRequestTypedDict",
    "CreatePaymentMethodGlobals",
    "CreatePaymentMethodGlobalsTypedDict",
    "CreatePaymentMethodNetworkTokenCryptogramGlobals",
    "CreatePaymentMethodNetworkTokenCryptogramGlobalsTypedDict",
    "CreatePaymentMethodNetworkTokenCryptogramRequest",
    "CreatePaymentMethodNetworkTokenCryptogramRequestTypedDict",
    "CreatePaymentMethodNetworkTokenGlobals",
    "CreatePaymentMethodNetworkTokenGlobalsTypedDict",
    "CreatePaymentMethodNetworkTokenRequest",
    "CreatePaymentMethodNetworkTokenRequestTypedDict",
    "CreatePaymentMethodPaymentServiceTokenGlobals",
    "CreatePaymentMethodPaymentServiceTokenGlobalsTypedDict",
    "CreatePaymentMethodPaymentServiceTokenRequest",
    "CreatePaymentMethodPaymentServiceTokenRequestTypedDict",
    "CreatePaymentMethodRequest",
    "CreatePaymentMethodRequestTypedDict",
    "CreatePaymentServiceDefinitionSessionRequest",
    "CreatePaymentServiceDefinitionSessionRequestTypedDict",
    "CreatePaymentServiceGlobals",
    "CreatePaymentServiceGlobalsTypedDict",
    "CreatePaymentServiceRequest",
    "CreatePaymentServiceRequestTypedDict",
    "CreatePaymentServiceSessionGlobals",
    "CreatePaymentServiceSessionGlobalsTypedDict",
    "CreatePaymentServiceSessionRequest",
    "CreatePaymentServiceSessionRequestTypedDict",
    "CreatePayoutGlobals",
    "CreatePayoutGlobalsTypedDict",
    "CreatePayoutRequest",
    "CreatePayoutRequestTypedDict",
    "CreateSession",
    "CreateSessionStatus",
    "CreateSessionTypedDict",
    "CreateTransactionGlobals",
    "CreateTransactionGlobalsTypedDict",
    "CreateTransactionRefundGlobals",
    "CreateTransactionRefundGlobalsTypedDict",
    "CreateTransactionRefundRequest",
    "CreateTransactionRefundRequestTypedDict",
    "CreateTransactionRequest",
    "CreateTransactionRequestTypedDict",
    "Creator",
    "CreatorTypedDict",
    "Cryptogram",
    "CryptogramCreate",
    "CryptogramCreateTypedDict",
    "CryptogramTypedDict",
    "DefinitionField",
    "DefinitionFieldFormat",
    "DefinitionFieldTypedDict",
    "DeleteBuyerGlobals",
    "DeleteBuyerGlobalsTypedDict",
    "DeleteBuyerRequest",
    "DeleteBuyerRequestTypedDict",
    "DeleteBuyerShippingDetailsGlobals",
    "DeleteBuyerShippingDetailsGlobalsTypedDict",
    "DeleteBuyerShippingDetailsRequest",
    "DeleteBuyerShippingDetailsRequestTypedDict",
    "DeleteCheckoutSessionGlobals",
    "DeleteCheckoutSessionGlobalsTypedDict",
    "DeleteCheckoutSessionRequest",
    "DeleteCheckoutSessionRequestTypedDict",
    "DeleteDigitalWalletGlobals",
    "DeleteDigitalWalletGlobalsTypedDict",
    "DeleteDigitalWalletRequest",
    "DeleteDigitalWalletRequestTypedDict",
    "DeleteGiftCardGlobals",
    "DeleteGiftCardGlobalsTypedDict",
    "DeleteGiftCardRequest",
    "DeleteGiftCardRequestTypedDict",
    "DeletePaymentMethodGlobals",
    "DeletePaymentMethodGlobalsTypedDict",
    "DeletePaymentMethodNetworkTokenGlobals",
    "DeletePaymentMethodNetworkTokenGlobalsTypedDict",
    "DeletePaymentMethodNetworkTokenRequest",
    "DeletePaymentMethodNetworkTokenRequestTypedDict",
    "DeletePaymentMethodPaymentServiceTokenGlobals",
    "DeletePaymentMethodPaymentServiceTokenGlobalsTypedDict",
    "DeletePaymentMethodPaymentServiceTokenRequest",
    "DeletePaymentMethodPaymentServiceTokenRequestTypedDict",
    "DeletePaymentMethodRequest",
    "DeletePaymentMethodRequestTypedDict",
    "DeletePaymentServiceGlobals",
    "DeletePaymentServiceGlobalsTypedDict",
    "DeletePaymentServiceRequest",
    "DeletePaymentServiceRequestTypedDict",
    "DigitalWallet",
    "DigitalWalletCreate",
    "DigitalWalletCreateTypedDict",
    "DigitalWalletDomain",
    "DigitalWalletDomainTypedDict",
    "DigitalWalletProvider",
    "DigitalWalletTypedDict",
    "DigitalWalletUpdate",
    "DigitalWalletUpdateTypedDict",
    "ErrorDetail",
    "ErrorDetailTypedDict",
    "ErrorLocation",
    "FieldT",
    "FieldTTypedDict",
    "GetBuyerGlobals",
    "GetBuyerGlobalsTypedDict",
    "GetBuyerRequest",
    "GetBuyerRequestTypedDict",
    "GetBuyerShippingDetailsGlobals",
    "GetBuyerShippingDetailsGlobalsTypedDict",
    "GetBuyerShippingDetailsRequest",
    "GetBuyerShippingDetailsRequestTypedDict",
    "GetCheckoutSessionGlobals",
    "GetCheckoutSessionGlobalsTypedDict",
    "GetCheckoutSessionRequest",
    "GetCheckoutSessionRequestTypedDict",
    "GetDigitalWalletGlobals",
    "GetDigitalWalletGlobalsTypedDict",
    "GetDigitalWalletRequest",
    "GetDigitalWalletRequestTypedDict",
    "GetGiftCardGlobals",
    "GetGiftCardGlobalsTypedDict",
    "GetGiftCardRequest",
    "GetGiftCardRequestTypedDict",
    "GetMerchantAccountRequest",
    "GetMerchantAccountRequestTypedDict",
    "GetPaymentMethodGlobals",
    "GetPaymentMethodGlobalsTypedDict",
    "GetPaymentMethodRequest",
    "GetPaymentMethodRequestTypedDict",
    "GetPaymentServiceDefinitionRequest",
    "GetPaymentServiceDefinitionRequestTypedDict",
    "GetPaymentServiceGlobals",
    "GetPaymentServiceGlobalsTypedDict",
    "GetPaymentServiceRequest",
    "GetPaymentServiceRequestTypedDict",
    "GetPayoutGlobals",
    "GetPayoutGlobalsTypedDict",
    "GetPayoutRequest",
    "GetPayoutRequestTypedDict",
    "GetRefundGlobals",
    "GetRefundGlobalsTypedDict",
    "GetRefundRequest",
    "GetRefundRequestTypedDict",
    "GetTransactionGlobals",
    "GetTransactionGlobalsTypedDict",
    "GetTransactionRefundGlobals",
    "GetTransactionRefundGlobalsTypedDict",
    "GetTransactionRefundRequest",
    "GetTransactionRefundRequestTypedDict",
    "GetTransactionRequest",
    "GetTransactionRequestTypedDict",
    "GetTransactionSummaryGlobals",
    "GetTransactionSummaryGlobalsTypedDict",
    "GetTransactionSummaryRequest",
    "GetTransactionSummaryRequestTypedDict",
    "GiftCard",
    "GiftCardBalanceRequest",
    "GiftCardBalanceRequestTypedDict",
    "GiftCardCreate",
    "GiftCardCreateTypedDict",
    "GiftCardErrorCode",
    "GiftCardRedemption",
    "GiftCardRedemptionStatus",
    "GiftCardRedemptionTypedDict",
    "GiftCardRequest",
    "GiftCardRequestTypedDict",
    "GiftCardService",
    "GiftCardServiceProvider",
    "GiftCardServiceTypedDict",
    "GiftCardStoredRequest",
    "GiftCardStoredRequestTypedDict",
    "GiftCardSummary",
    "GiftCardSummaryTypedDict",
    "GiftCardTokenTransactionCreate",
    "GiftCardTokenTransactionCreateTypedDict",
    "GiftCardTransactionCreate",
    "GiftCardTransactionCreateTypedDict",
    "GiftCardTypedDict",
    "GiftCardUnion",
    "GiftCardUnionTypedDict",
    "GooglePayAssuranceDetails",
    "GooglePayAssuranceDetailsTypedDict",
    "GooglePayFPANPaymentMethodCreate",
    "GooglePayFPANPaymentMethodCreateTypedDict",
    "GooglePayPaymentMethodCreate",
    "GooglePayPaymentMethodCreateTypedDict",
    "GooglePayPaymentOptionContext",
    "GooglePayPaymentOptionContextTypedDict",
    "GooglePaySession",
    "GooglePaySessionRequest",
    "GooglePaySessionRequestTypedDict",
    "GooglePaySessionTypedDict",
    "GuestBuyerInput",
    "GuestBuyerInputTypedDict",
    "GuestBuyerOutput",
    "GuestBuyerOutputTypedDict",
    "InstrumentType",
    "Item",
    "ItemTypedDict",
    "ListAuditLogsGlobals",
    "ListAuditLogsGlobalsTypedDict",
    "ListAuditLogsRequest",
    "ListAuditLogsRequestTypedDict",
    "ListAuditLogsResponse",
    "ListAuditLogsResponseTypedDict",
    "ListBuyerGiftCardsGlobals",
    "ListBuyerGiftCardsGlobalsTypedDict",
    "ListBuyerGiftCardsRequest",
    "ListBuyerGiftCardsRequestTypedDict",
    "ListBuyerPaymentMethodsGlobals",
    "ListBuyerPaymentMethodsGlobalsTypedDict",
    "ListBuyerPaymentMethodsRequest",
    "ListBuyerPaymentMethodsRequestTypedDict",
    "ListBuyerShippingDetailsGlobals",
    "ListBuyerShippingDetailsGlobalsTypedDict",
    "ListBuyerShippingDetailsRequest",
    "ListBuyerShippingDetailsRequestTypedDict",
    "ListBuyersGlobals",
    "ListBuyersGlobalsTypedDict",
    "ListBuyersRequest",
    "ListBuyersRequestTypedDict",
    "ListBuyersResponse",
    "ListBuyersResponseTypedDict",
    "ListCardSchemeDefinitionsGlobals",
    "ListCardSchemeDefinitionsGlobalsTypedDict",
    "ListCardSchemeDefinitionsRequest",
    "ListCardSchemeDefinitionsRequestTypedDict",
    "ListDigitalWalletsGlobals",
    "ListDigitalWalletsGlobalsTypedDict",
    "ListDigitalWalletsRequest",
    "ListDigitalWalletsRequestTypedDict",
    "ListGiftCardBalancesGlobals",
    "ListGiftCardBalancesGlobalsTypedDict",
    "ListGiftCardBalancesRequest",
    "ListGiftCardBalancesRequestTypedDict",
    "ListGiftCardsGlobals",
    "ListGiftCardsGlobalsTypedDict",
    "ListGiftCardsRequest",
    "ListGiftCardsRequestTypedDict",
    "ListGiftCardsResponse",
    "ListGiftCardsResponseTypedDict",
    "ListMerchantAccountsRequest",
    "ListMerchantAccountsRequestTypedDict",
    "ListMerchantAccountsResponse",
    "ListMerchantAccountsResponseTypedDict",
    "ListPaymentMethodNetworkTokensGlobals",
    "ListPaymentMethodNetworkTokensGlobalsTypedDict",
    "ListPaymentMethodNetworkTokensRequest",
    "ListPaymentMethodNetworkTokensRequestTypedDict",
    "ListPaymentMethodPaymentServiceTokensGlobals",
    "ListPaymentMethodPaymentServiceTokensGlobalsTypedDict",
    "ListPaymentMethodPaymentServiceTokensRequest",
    "ListPaymentMethodPaymentServiceTokensRequestTypedDict",
    "ListPaymentMethodsGlobals",
    "ListPaymentMethodsGlobalsTypedDict",
    "ListPaymentMethodsRequest",
    "ListPaymentMethodsRequestTypedDict",
    "ListPaymentMethodsResponse",
    "ListPaymentMethodsResponseTypedDict",
    "ListPaymentOptionsGlobals",
    "ListPaymentOptionsGlobalsTypedDict",
    "ListPaymentOptionsRequest",
    "ListPaymentOptionsRequestTypedDict",
    "ListPaymentServiceDefinitionsRequest",
    "ListPaymentServiceDefinitionsRequestTypedDict",
    "ListPaymentServiceDefinitionsResponse",
    "ListPaymentServiceDefinitionsResponseTypedDict",
    "ListPaymentServicesGlobals",
    "ListPaymentServicesGlobalsTypedDict",
    "ListPaymentServicesRequest",
    "ListPaymentServicesRequestTypedDict",
    "ListPaymentServicesResponse",
    "ListPaymentServicesResponseTypedDict",
    "ListPayoutsGlobals",
    "ListPayoutsGlobalsTypedDict",
    "ListPayoutsRequest",
    "ListPayoutsRequestTypedDict",
    "ListPayoutsResponse",
    "ListPayoutsResponseTypedDict",
    "ListTransactionRefundsGlobals",
    "ListTransactionRefundsGlobalsTypedDict",
    "ListTransactionRefundsRequest",
    "ListTransactionRefundsRequestTypedDict",
    "ListTransactionsGlobals",
    "ListTransactionsGlobalsTypedDict",
    "ListTransactionsRequest",
    "ListTransactionsRequestTypedDict",
    "ListTransactionsResponse",
    "ListTransactionsResponseTypedDict",
    "Loc",
    "LocTypedDict",
    "MerchantAccount",
    "MerchantAccountCreate",
    "MerchantAccountCreateTypedDict",
    "MerchantAccountTypedDict",
    "MerchantAccountUpdate",
    "MerchantAccountUpdateTypedDict",
    "MerchantProfileScheme",
    "MerchantProfileSchemeSummary",
    "MerchantProfileSchemeSummaryTypedDict",
    "MerchantProfileSchemeTypedDict",
    "Method",
    "Mode",
    "NetworkToken",
    "NetworkTokenCreate",
    "NetworkTokenCreateTypedDict",
    "NetworkTokenPaymentMethodCreate",
    "NetworkTokenPaymentMethodCreateTypedDict",
    "NetworkTokenStatus",
    "NetworkTokenTypedDict",
    "OrderBy",
    "PaymentMethod",
    "PaymentMethodCard",
    "PaymentMethodCardTypedDict",
    "PaymentMethodDetailsCard",
    "PaymentMethodDetailsCardTypedDict",
    "PaymentMethodStatus",
    "PaymentMethodStoredCard",
    "PaymentMethodStoredCardTypedDict",
    "PaymentMethodSummary",
    "PaymentMethodSummaryTypedDict",
    "PaymentMethodTypedDict",
    "PaymentOption",
    "PaymentOptionContext",
    "PaymentOptionContextApprovalUI",
    "PaymentOptionContextApprovalUITypedDict",
    "PaymentOptionContextTypedDict",
    "PaymentOptionRequest",
    "PaymentOptionRequestTypedDict",
    "PaymentOptionTypedDict",
    "PaymentService",
    "PaymentServiceConfiguration",
    "PaymentServiceConfigurationTypedDict",
    "PaymentServiceCreate",
    "PaymentServiceCreateTypedDict",
    "PaymentServiceDefinition",
    "PaymentServiceDefinitionTypedDict",
    "PaymentServiceStatus",
    "PaymentServiceToken",
    "PaymentServiceTokenCreate",
    "PaymentServiceTokenCreateTypedDict",
    "PaymentServiceTokenTypedDict",
    "PaymentServiceTypedDict",
    "PaymentServiceUpdate",
    "PaymentServiceUpdateTypedDict",
    "PayoutCategory",
    "PayoutCreate",
    "PayoutCreatePaymentMethod",
    "PayoutCreatePaymentMethodTypedDict",
    "PayoutCreateTypedDict",
    "PayoutMerchant",
    "PayoutMerchantSummary",
    "PayoutMerchantSummaryTypedDict",
    "PayoutMerchantTypedDict",
    "PayoutPaymentService",
    "PayoutPaymentServiceTypedDict",
    "PayoutStatus",
    "PayoutSummary",
    "PayoutSummaryTypedDict",
    "ProductType",
    "Recipient",
    "RecipientTypedDict",
    "RedirectPaymentMethodCreate",
    "RedirectPaymentMethodCreateMethod",
    "RedirectPaymentMethodCreateTypedDict",
    "Refund",
    "RefundStatus",
    "RefundTargetType",
    "RefundTypedDict",
    "RegisterDigitalWalletDomainGlobals",
    "RegisterDigitalWalletDomainGlobalsTypedDict",
    "RegisterDigitalWalletDomainRequest",
    "RegisterDigitalWalletDomainRequestTypedDict",
    "RequiredCheckoutFields",
    "RequiredCheckoutFieldsTypedDict",
    "RequiredFields1",
    "RequiredFields1TypedDict",
    "RequiredFields2",
    "RequiredFields2TypedDict",
    "ResponseData",
    "ResponseDataTypedDict",
    "ResumePaymentMethodNetworkTokenGlobals",
    "ResumePaymentMethodNetworkTokenGlobalsTypedDict",
    "ResumePaymentMethodNetworkTokenRequest",
    "ResumePaymentMethodNetworkTokenRequestTypedDict",
    "RouteType",
    "Security",
    "SecurityTypedDict",
    "ShippingDetails",
    "ShippingDetailsCreate",
    "ShippingDetailsCreateTypedDict",
    "ShippingDetailsTypedDict",
    "ShippingDetailsUpdate",
    "ShippingDetailsUpdateTypedDict",
    "StatementDescriptor",
    "StatementDescriptorTypedDict",
    "SuspendPaymentMethodNetworkTokenGlobals",
    "SuspendPaymentMethodNetworkTokenGlobalsTypedDict",
    "SuspendPaymentMethodNetworkTokenRequest",
    "SuspendPaymentMethodNetworkTokenRequestTypedDict",
    "SyncTransactionGlobals",
    "SyncTransactionGlobalsTypedDict",
    "SyncTransactionRequest",
    "SyncTransactionRequestTypedDict",
    "TaxID",
    "TaxIDKind",
    "TaxIDTypedDict",
    "ThreeDSecureData",
    "ThreeDSecureDataTypedDict",
    "ThreeDSecureDataV1",
    "ThreeDSecureDataV1TypedDict",
    "ThreeDSecureDataV2",
    "ThreeDSecureDataV2TypedDict",
    "ThreeDSecureError",
    "ThreeDSecureErrorTypedDict",
    "ThreeDSecureMethod",
    "ThreeDSecureStatus",
    "ThreeDSecureV2",
    "ThreeDSecureV2TypedDict",
    "TicketDeliveryMethod",
    "Token",
    "TokenPaymentMethodCreate",
    "TokenPaymentMethodCreateTypedDict",
    "TokenTypedDict",
    "Transaction",
    "TransactionBuyer",
    "TransactionBuyerTypedDict",
    "TransactionCapture",
    "TransactionCaptureTypedDict",
    "TransactionCreate",
    "TransactionCreatePaymentMethod",
    "TransactionCreatePaymentMethodTypedDict",
    "TransactionCreateTypedDict",
    "TransactionGiftCard",
    "TransactionGiftCardTypedDict",
    "TransactionIntent",
    "TransactionIntentOutcome",
    "TransactionPaymentMethod",
    "TransactionPaymentMethodTypedDict",
    "TransactionPaymentService",
    "TransactionPaymentServiceTypedDict",
    "TransactionPaymentSource",
    "TransactionRefundAllCreate",
    "TransactionRefundAllCreateTypedDict",
    "TransactionRefundCreate",
    "TransactionRefundCreateTypedDict",
    "TransactionStatus",
    "TransactionStatusSummary",
    "TransactionStatusSummaryTypedDict",
    "TransactionSummary",
    "TransactionSummaryTypedDict",
    "TransactionThreeDSecureSummary",
    "TransactionThreeDSecureSummaryTypedDict",
    "TransactionTypedDict",
    "UnregisterDigitalWalletDomainGlobals",
    "UnregisterDigitalWalletDomainGlobalsTypedDict",
    "UnregisterDigitalWalletDomainRequest",
    "UnregisterDigitalWalletDomainRequestTypedDict",
    "UpdateBuyerGlobals",
    "UpdateBuyerGlobalsTypedDict",
    "UpdateBuyerRequest",
    "UpdateBuyerRequestTypedDict",
    "UpdateBuyerShippingDetailsGlobals",
    "UpdateBuyerShippingDetailsGlobalsTypedDict",
    "UpdateBuyerShippingDetailsRequest",
    "UpdateBuyerShippingDetailsRequestTypedDict",
    "UpdateCheckoutSessionGlobals",
    "UpdateCheckoutSessionGlobalsTypedDict",
    "UpdateCheckoutSessionRequest",
    "UpdateCheckoutSessionRequestTypedDict",
    "UpdateDigitalWalletGlobals",
    "UpdateDigitalWalletGlobalsTypedDict",
    "UpdateDigitalWalletRequest",
    "UpdateDigitalWalletRequestTypedDict",
    "UpdateMerchantAccountRequest",
    "UpdateMerchantAccountRequestTypedDict",
    "UpdatePaymentServiceGlobals",
    "UpdatePaymentServiceGlobalsTypedDict",
    "UpdatePaymentServiceRequest",
    "UpdatePaymentServiceRequestTypedDict",
    "UserDevice",
    "UserStatus",
    "ValidationError",
    "ValidationErrorTypedDict",
    "VerifyCredentials",
    "VerifyCredentialsTypedDict",
    "VerifyPaymentServiceCredentialsGlobals",
    "VerifyPaymentServiceCredentialsGlobalsTypedDict",
    "VerifyPaymentServiceCredentialsRequest",
    "VerifyPaymentServiceCredentialsRequestTypedDict",
    "VoidTransactionGlobals",
    "VoidTransactionGlobalsTypedDict",
    "VoidTransactionRequest",
    "VoidTransactionRequestTypedDict",
    "VoidableField",
    "VoidableFieldTypedDict",
    "WalletPaymentOptionContext",
    "WalletPaymentOptionContextTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

# pyright: reportReturnType = false
import asyncio
from typing_extensions import Protocol, runtime_checkable
import httpx
from typing import Any, Optional, Union


@runtime_checkable
class HttpClient(Protocol):
    def send(
        self,
        request: httpx.Request,
        *,
        stream: bool = False,
        auth: Union[
            httpx._types.AuthTypes, httpx._client.UseClientDefault, None
        ] = httpx.USE_CLIENT_DEFAULT,
        follow_redirects: Union[
            bool, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
    ) -> httpx.Response:
        pass

    def build_request(
        self,
        method: str,
        url: httpx._types.URLTypes,
        *,
        content: Optional[httpx._types.RequestContent] = None,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        params: Optional[httpx._types.QueryParamTypes] = None,
        headers: Optional[httpx._types.HeaderTypes] = None,
        cookies: Optional[httpx._types.CookieTypes] = None,
        timeout: Union[
            httpx._types.TimeoutTypes, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
        extensions: Optional[httpx._types.RequestExtensions] = None,
    ) -> httpx.Request:
        pass

    def close(self) -> None:
        pass


@runtime_checkable
class AsyncHttpClient(Protocol):
    async def send(
        self,
        request: httpx.Request,
        *,
        stream: bool = False,
        auth: Union[
            httpx._types.AuthTypes, httpx._client.UseClientDefault, None
        ] = httpx.USE_CLIENT_DEFAULT,
        follow_redirects: Union[
            bool, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
    ) -> httpx.Response:
        pass

    def build_request(
        self,
        method: str,
        url: httpx._types.URLTypes,
        *,
        content: Optional[httpx._types.RequestContent] = None,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        params: Optional[httpx._types.QueryParamTypes] = None,
        headers: Optional[httpx._types.HeaderTypes] = None,
        cookies: Optional[httpx._types.CookieTypes] = None,
        timeout: Union[
            httpx._types.TimeoutTypes, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
        extensions: Optional[httpx._types.RequestExtensions] = None,
    ) -> httpx.Request:
        pass

    async def aclose(self) -> None:
        pass


class ClientOwner(Protocol):
    client: Union[HttpClient, None]
    async_client: Union[AsyncHttpClient, None]


def close_clients(
    owner: ClientOwner,
    sync_client: Union[HttpClient, None],
    sync_client_supplied: bool,
    async_client: Union[AsyncHttpClient, None],
    async_client_supplied: bool,
) -> None:
    """
    A finalizer function that is meant to be used with weakref.finalize to close
    httpx clients used by an SDK so that underlying resources can be garbage
    collected.
    """

    # Unset the client/async_client properties so there are no more references
    # to them from the owning SDK instance and they can be reaped.
    owner.client = None
    owner.async_client = None

    if sync_client is not None and not sync_client_supplied:
        try:
            sync_client.close()
        except Exception:
            pass

    if async_client is not None and not async_client_supplied:
        # First, try the simplest approach - use asyncio.run()
        # This works when we're not in an async context
        try:
            asyncio.run(async_client.aclose())
        except RuntimeError as e:
            # If we get "RuntimeError: This event loop is already running",
            # it means we're in an async context
            if "already running" in str(e):
                try:
                    # We're in an async context, so get the running loop
                    loop = asyncio.get_running_loop()
                    # Create a task but don't wait for it
                    loop.create_task(async_client.aclose())
                except Exception:
                    # If we can't get the loop or create a task, just ignore
                    # The GC will eventually clean up the resources
                    pass
            # If we get "RuntimeError: There is no current event loop in thread",
            # we're not in an async context, but asyncio.run() failed for some reason
            # In this case, we can try to create a new event loop explicitly
            elif "no current event loop" in str(e):
                try:
                    # Create a new event loop and run the coroutine
                    loop = asyncio.new_event_loop()
                    asyncio.set_event_loop(loop)
                    try:
                        loop.run_until_complete(async_client.aclose())
                    finally:
                        loop.close()
                        asyncio.set_event_loop(None)
                except Exception:
                    # If this also fails, just ignore
                    pass
            # For any other RuntimeError, just ignore
            else:
                pass
        except Exception:
            # For any other exception, just ignore
            pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentoption import PaymentOption, PaymentOptionTypedDict
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CollectionNoCursorPaymentOptionTypedDict(TypedDict):
    items: List[PaymentOptionTypedDict]
    r"""A list of items returned for this request."""


class CollectionNoCursorPaymentOption(BaseModel):
    items: List[PaymentOption]
    r"""A list of items returned for this request."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from gr4vy.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    QueryParamMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteGiftCardGlobalsTypedDict(TypedDict):
    merchant_account_id: NotRequired[str]
    r"""The ID of the merchant account to use for this request."""


class DeleteGiftCardGlobals(BaseModel):
    merchant_account_id: Annotated[
        Optional[str],
        pydantic.Field(alias="x-gr4vy-merchant-account-id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The ID of the merchant account to use for this request."""


class DeleteGiftCardRequestTypedDict(TypedDict):
    gift_card_id: str
    r"""The ID of the gift card."""
    timeout_in_seconds: NotRequired[float]
    merchant_account_id: NotRequired[str]
    r"""The ID of the merchant account to use for this request."""


class DeleteGiftCardRequest(BaseModel):
    gift_card_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the gift card."""

    timeout_in_seconds: Annotated[
        Optional[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1

    merchant_account_id: Annotated[
        Optional[str],
        pydantic.Field(alias="x-gr4vy-merchant-account-id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The ID of the merchant account to use for this request."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .connectionoptions import ConnectionOptions, ConnectionOptionsTypedDict
from .guestbuyer_input import GuestBuyerInput, GuestBuyerInputTypedDict
from .paymentmethodcard import PaymentMethodCard, PaymentMethodCardTypedDict
from .paymentmethodstoredcard import (
    PaymentMethodStoredCard,
    PaymentMethodStoredCardTypedDict,
)
from .payoutcategory import PayoutCategory
from .payoutmerchant import PayoutMerchant, PayoutMerchantTypedDict
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from gr4vy.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


PayoutCreatePaymentMethodTypedDict = TypeAliasType(
    "PayoutCreatePaymentMethodTypedDict",
    Union[PaymentMethodStoredCardTypedDict, PaymentMethodCardTypedDict],
)
r"""The type of payment method to send funds too."""


PayoutCreatePaymentMethod = TypeAliasType(
    "PayoutCreatePaymentMethod", Union[PaymentMethodStoredCard, PaymentMethodCard]
)
r"""The type of payment method to send funds too."""


class PayoutCreateTypedDict(TypedDict):
    r"""PayoutCreate

    Represents the data required to create a new payout.
    """

    amount: int
    r"""The monetary amount for this payout, in the smallest currency unit for the given currency, for example `1299` cents to create an authorization for $12.99."""
    currency: str
    r"""The ISO-4217 currency code for this payout."""
    payment_service_id: str
    r"""The ID of the payment service to use for the payout."""
    payment_method: PayoutCreatePaymentMethodTypedDict
    r"""The type of payment method to send funds too."""
    category: NotRequired[Nullable[PayoutCategory]]
    r"""The type of payout to process."""
    external_identifier: NotRequired[Nullable[str]]
    r"""A value that can be used to match the payout against your own records."""
    buyer_id: NotRequired[Nullable[str]]
    r"""The `id` of a stored buyer to use for this payout Use this instead of the `buyer` or `buyer_external_identifier`."""
    buyer: NotRequired[Nullable[GuestBuyerInputTypedDict]]
    r"""Inline buyer details for the payout. Use this instead of the `buyer_id` or `buyer_external_identifier`."""
    buyer_external_identifier: NotRequired[Nullable[str]]
    r"""The `external_identifier` of a stored buyer to use for this payout. Use this instead of the `buyer_id` or `buyer`."""
    merchant: NotRequired[Nullable[PayoutMerchantTypedDict]]
    r"""Merchant information for the source of the payout."""
    connection_options: NotRequired[Nullable[ConnectionOptionsTypedDict]]
    r"""Optional fields for processing payouts on specific payment services."""


class PayoutCreate(BaseModel):
    r"""PayoutCreate

    Represents the data required to create a new payout.
    """

    amount: int
    r"""The monetary amount for this payout, in the smallest currency unit for the given currency, for example `1299` cents to create an authorization for $12.99."""

    currency: str
    r"""The ISO-4217 currency code for this payout."""

    payment_service_id: str
    r"""The ID of the payment service to use for the payout."""

    payment_method: PayoutCreatePaymentMethod
    r"""The type of payment method to send funds too."""

    category: Annotated[
        OptionalNullable[PayoutCategory], PlainValidator(validate_open_enum(False))
    ] = UNSET
    r"""The type of payout to process."""

    external_identifier: OptionalNullable[str] = UNSET
    r"""A value that can be used to match the payout against your own records."""

    buyer_id: OptionalNullable[str] = UNSET
    r"""The `id` of a stored buyer to use for this payout Use this instead of the `buyer` or `buyer_external_identifier`."""

    buyer: OptionalNullable[GuestBuyerInput] = UNSET
    r"""Inline buyer details for the payout. Use this instead of the `buyer_id` or `buyer_external_identifier`."""

    buyer_external_identifier: OptionalNullable[str] = UNSET
    r"""The `external_identifier` of a stored buyer to use for this payout. Use this instead of the `buyer_id` or `buyer`."""

    merchant: OptionalNullable[PayoutMerchant] = UNSET
    r"""Merchant information for the source of the payout."""

    connection_options: OptionalNullable[ConnectionOptions] = UNSET
    r"""Optional fields for processing payouts on specific payment services."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "category",
            "external_identifier",
            "buyer_id",
            "buyer",
            "buyer_external_identifier",
            "merchant",
            "connection_options",
        ]
        nullable_fields = [
            "category",
            "external_identifier",
            "buyer_id",
            "buyer",
            "buyer_external_identifier",
            "merchant",
            "connection_options",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .transactionstatus import TransactionStatus
from gr4vy.types import BaseModel
from gr4vy.utils import validate_const, validate_open_enum
import pydantic
from pydantic.functional_validators import AfterValidator, PlainValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class TransactionStatusSummaryTypedDict(TypedDict):
    id: str
    r"""The ID for the transaction."""
    status: TransactionStatus
    type: Literal["transaction"]
    r"""Always `transaction`."""


class TransactionStatusSummary(BaseModel):
    id: str
    r"""The ID for the transaction."""

    status: Annotated[TransactionStatus, PlainValidator(validate_open_enum(False))]

    TYPE: Annotated[
        Annotated[
            Optional[Literal["transaction"]],
            AfterValidator(validate_const("transaction")),
        ],
        pydantic.Field(alias="type"),
    ] = "transaction"
    r"""Always `transaction`."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .add_buyer_shipping_detailsop import (
    Response403AddBuyerShippingDetails,
    Response403AddBuyerShippingDetailsUnion,
)
from .add_buyerop import Response403AddBuyer, Response403AddBuyerUnion
from .apierror import APIError
from .capture_transactionop import (
    Response403CaptureTransaction,
    Response403CaptureTransactionUnion,
)
from .configure_digital_walletop import (
    Response403ConfigureDigitalWallet,
    Response403ConfigureDigitalWalletUnion,
)
from .create_account_updater_jobop import (
    Response403CreateAccountUpdaterJob,
    Response403CreateAccountUpdaterJobUnion,
)
from .create_apple_pay_digital_wallet_sessionop import (
    Response403CreateApplePayDigitalWalletSession,
    Response403CreateApplePayDigitalWalletSessionUnion,
)
from .create_checkout_sessionop import (
    Response403CreateCheckoutSession,
    Response403CreateCheckoutSessionUnion,
)
from .create_click_to_pay_digital_wallet_sessionop import (
    Response403CreateClickToPayDigitalWalletSession,
    Response403CreateClickToPayDigitalWalletSessionUnion,
)
from .create_full_transaction_refundop import (
    Response403CreateFullTransactionRefund,
    Response403CreateFullTransactionRefundUnion,
)
from .create_gift_cardop import (
    Response403CreateGiftCard,
    Response403CreateGiftCardUnion,
)
from .create_google_pay_digital_wallet_sessionop import (
    Response403CreateGooglePayDigitalWalletSession,
    Response403CreateGooglePayDigitalWalletSessionUnion,
)
from .create_merchant_accountop import (
    Response403CreateMerchantAccount,
    Response403CreateMerchantAccountUnion,
)
from .create_payment_method_network_token_cryptogramop import (
    Response403CreatePaymentMethodNetworkTokenCryptogram,
    Response403CreatePaymentMethodNetworkTokenCryptogramUnion,
)
from .create_payment_method_network_tokenop import (
    Response403CreatePaymentMethodNetworkToken,
    Response403CreatePaymentMethodNetworkTokenUnion,
)
from .create_payment_method_payment_service_tokenop import (
    Response403CreatePaymentMethodPaymentServiceToken,
    Response403CreatePaymentMethodPaymentServiceTokenUnion,
)
from .create_payment_methodop import (
    Response403CreatePaymentMethod,
    Response403CreatePaymentMethodUnion,
)
from .create_payment_service_definition_sessionop import (
    Response403CreatePaymentServiceDefinitionSession,
    Response403CreatePaymentServiceDefinitionSessionUnion,
)
from .create_payment_service_sessionop import (
    Response403CreatePaymentServiceSession,
    Response403CreatePaymentServiceSessionUnion,
)
from .create_payment_serviceop import (
    Response403CreatePaymentService,
    Response403CreatePaymentServiceUnion,
)
from .create_payoutop import Response403CreatePayout, Response403CreatePayoutUnion
from .create_transaction_refundop import (
    Response403CreateTransactionRefund,
    Response403CreateTransactionRefundUnion,
)
from .create_transactionop import (
    Response403CreateTransaction,
    Response403CreateTransactionUnion,
)
from .delete_buyer_shipping_detailsop import (
    Response403DeleteBuyerShippingDetails,
    Response403DeleteBuyerShippingDetailsUnion,
)
from .delete_buyerop import Response403DeleteBuyer, Response403DeleteBuyerUnion
from .delete_checkout_sessionop import (
    Response403DeleteCheckoutSession,
    Response403DeleteCheckoutSessionUnion,
)
from .delete_digital_walletop import (
    Response403DeleteDigitalWallet,
    Response403DeleteDigitalWalletUnion,
)
from .delete_gift_cardop import (
    Response403DeleteGiftCard,
    Response403DeleteGiftCardUnion,
)
from .delete_payment_method_network_tokenop import (
    Response403DeletePaymentMethodNetworkToken,
    Response403DeletePaymentMethodNetworkTokenUnion,
)
from .delete_payment_method_payment_service_tokenop import (
    Response403DeletePaymentMethodPaymentServiceToken,
    Response403DeletePaymentMethodPaymentServiceTokenUnion,
)
from .delete_payment_methodop import (
    Response403DeletePaymentMethod,
    Response403DeletePaymentMethodUnion,
)
from .delete_payment_serviceop import (
    Response403DeletePaymentService,
    Response403DeletePaymentServiceUnion,
)
from .error400 import Error400, Error400Data
from .error401 import Error401, Error401Data
from .error403 import Error403, Error403Data
from .error403active import Error403Active, Error403ActiveData
from .error403forbidden import Error403Forbidden, Error403ForbiddenData
from .error404 import Error404, Error404Data
from .error405 import Error405, Error405Data
from .error409 import Error409, Error409Data
from .error425 import Error425, Error425Data
from .error429 import Error429, Error429Data
from .error500 import Error500, Error500Data
from .error502 import Error502, Error502Data
from .error504 import Error504, Error504Data
from .get_buyer_shipping_detailsop import (
    Response403GetBuyerShippingDetails,
    Response403GetBuyerShippingDetailsUnion,
)
from .get_buyerop import Response403GetBuyer, Response403GetBuyerUnion
from .get_checkout_sessionop import (
    Response403GetCheckoutSession,
    Response403GetCheckoutSessionUnion,
)
from .get_digital_walletop import (
    Response403GetDigitalWallet,
    Response403GetDigitalWalletUnion,
)
from .get_gift_cardop import Response403GetGiftCard, Response403GetGiftCardUnion
from .get_merchant_accountop import (
    Response403GetMerchantAccount,
    Response403GetMerchantAccountUnion,
)
from .get_payment_methodop import (
    Response403GetPaymentMethod,
    Response403GetPaymentMethodUnion,
)
from .get_payment_service_definitionop import (
    Response403GetPaymentServiceDefinition,
    Response403GetPaymentServiceDefinitionUnion,
)
from .get_payment_serviceop import (
    Response403GetPaymentService,
    Response403GetPaymentServiceUnion,
)
from .get_payoutop import Response403GetPayout, Response403GetPayoutUnion
from .get_refundop import Response403GetRefund, Response403GetRefundUnion
from .get_transaction_refundop import (
    Response403GetTransactionRefund,
    Response403GetTransactionRefundUnion,
)
from .get_transaction_summaryop import (
    Response403GetTransactionSummary,
    Response403GetTransactionSummaryUnion,
)
from .get_transactionop import Response403GetTransaction, Response403GetTransactionUnion
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .list_audit_logsop import Response403ListAuditLogs, Response403ListAuditLogsUnion
from .list_buyer_gift_cardsop import (
    Response403ListBuyerGiftCards,
    Response403ListBuyerGiftCardsUnion,
)
from .list_buyer_payment_methodsop import (
    Response403ListBuyerPaymentMethods,
    Response403ListBuyerPaymentMethodsUnion,
)
from .list_buyer_shipping_detailsop import (
    Response403ListBuyerShippingDetails,
    Response403ListBuyerShippingDetailsUnion,
)
from .list_buyersop import Response403ListBuyers, Response403ListBuyersUnion
from .list_card_scheme_definitionsop import (
    Response403ListCardSchemeDefinitions,
    Response403ListCardSchemeDefinitionsUnion,
)
from .list_digital_walletsop import (
    Response403ListDigitalWallets,
    Response403ListDigitalWalletsUnion,
)
from .list_gift_card_balancesop import (
    Response403ListGiftCardBalances,
    Response403ListGiftCardBalancesUnion,
)
from .list_gift_cardsop import Response403ListGiftCards, Response403ListGiftCardsUnion
from .list_merchant_accountsop import (
    Response403ListMerchantAccounts,
    Response403ListMerchantAccountsUnion,
)
from .list_payment_method_network_tokensop import (
    Response403ListPaymentMethodNetworkTokens,
    Response403ListPaymentMethodNetworkTokensUnion,
)
from .list_payment_method_payment_service_tokensop import (
    Response403ListPaymentMethodPaymentServiceTokens,
    Response403ListPaymentMethodPaymentServiceTokensUnion,
)
from .list_payment_methodsop import (
    Response403ListPaymentMethods,
    Response403ListPaymentMethodsUnion,
)
from .list_payment_optionsop import (
    Response403ListPaymentOptions,
    Response403ListPaymentOptionsUnion,
)
from .list_payment_service_definitionsop import (
    Response403ListPaymentServiceDefinitions,
    Response403ListPaymentServiceDefinitionsUnion,
)
from .list_payment_servicesop import (
    Response403ListPaymentServices,
    Response403ListPaymentServicesUnion,
)
from .list_payoutsop import Response403ListPayouts, Response403ListPayoutsUnion
from .list_transaction_refundsop import (
    Response403ListTransactionRefunds,
    Response403ListTransactionRefundsUnion,
)
from .list_transactionsop import (
    Response403ListTransactions,
    Response403ListTransactionsUnion,
)
from .register_digital_wallet_domainop import (
    Response403RegisterDigitalWalletDomain,
    Response403RegisterDigitalWalletDomainUnion,
)
from .resume_payment_method_network_tokenop import (
    Response403ResumePaymentMethodNetworkToken,
    Response403ResumePaymentMethodNetworkTokenUnion,
)
from .suspend_payment_method_network_tokenop import (
    Response403SuspendPaymentMethodNetworkToken,
    Response403SuspendPaymentMethodNetworkTokenUnion,
)
from .sync_transactionop import (
    Response403SyncTransaction,
    Response403SyncTransactionUnion,
)
from .unregister_digital_wallet_domainop import (
    Response403UnregisterDigitalWalletDomain,
    Response403UnregisterDigitalWalletDomainUnion,
)
from .update_buyer_shipping_detailsop import (
    Response403UpdateBuyerShippingDetails,
    Response403UpdateBuyerShippingDetailsUnion,
)
from .update_buyerop import Response403UpdateBuyer, Response403UpdateBuyerUnion
from .update_checkout_sessionop import (
    Response403UpdateCheckoutSession,
    Response403UpdateCheckoutSessionUnion,
)
from .update_digital_walletop import (
    Response403UpdateDigitalWallet,
    Response403UpdateDigitalWalletUnion,
)
from .update_merchant_accountop import (
    Response403UpdateMerchantAccount,
    Response403UpdateMerchantAccountUnion,
)
from .update_payment_serviceop import (
    Response403UpdatePaymentService,
    Response403UpdatePaymentServiceUnion,
)
from .verify_payment_service_credentialsop import (
    Response403VerifyPaymentServiceCredentials,
    Response403VerifyPaymentServiceCredentialsUnion,
)
from .void_transactionop import (
    Response403VoidTransaction,
    Response403VoidTransactionUnion,
)


__all__ = [
    "APIError",
    "Error400",
    "Error400Data",
    "Error401",
    "Error401Data",
    "Error403",
    "Error403Active",
    "Error403ActiveData",
    "Error403Data",
    "Error403Forbidden",
    "Error403ForbiddenData",
    "Error404",
    "Error404Data",
    "Error405",
    "Error405Data",
    "Error409",
    "Error409Data",
    "Error425",
    "Error425Data",
    "Error429",
    "Error429Data",
    "Error500",
    "Error500Data",
    "Error502",
    "Error502Data",
    "Error504",
    "Error504Data",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "Response403AddBuyer",
    "Response403AddBuyerShippingDetails",
    "Response403AddBuyerShippingDetailsUnion",
    "Response403AddBuyerUnion",
    "Response403CaptureTransaction",
    "Response403CaptureTransactionUnion",
    "Response403ConfigureDigitalWallet",
    "Response403ConfigureDigitalWalletUnion",
    "Response403CreateAccountUpdaterJob",
    "Response403CreateAccountUpdaterJobUnion",
    "Response403CreateApplePayDigitalWalletSession",
    "Response403CreateApplePayDigitalWalletSessionUnion",
    "Response403CreateCheckoutSession",
    "Response403CreateCheckoutSessionUnion",
    "Response403CreateClickToPayDigitalWalletSession",
    "Response403CreateClickToPayDigitalWalletSessionUnion",
    "Response403CreateFullTransactionRefund",
    "Response403CreateFullTransactionRefundUnion",
    "Response403CreateGiftCard",
    "Response403CreateGiftCardUnion",
    "Response403CreateGooglePayDigitalWalletSession",
    "Response403CreateGooglePayDigitalWalletSessionUnion",
    "Response403CreateMerchantAccount",
    "Response403CreateMerchantAccountUnion",
    "Response403CreatePaymentMethod",
    "Response403CreatePaymentMethodNetworkToken",
    "Response403CreatePaymentMethodNetworkTokenCryptogram",
    "Response403CreatePaymentMethodNetworkTokenCryptogramUnion",
    "Response403CreatePaymentMethodNetworkTokenUnion",
    "Response403CreatePaymentMethodPaymentServiceToken",
    "Response403CreatePaymentMethodPaymentServiceTokenUnion",
    "Response403CreatePaymentMethodUnion",
    "Response403CreatePaymentService",
    "Response403CreatePaymentServiceDefinitionSession",
    "Response403CreatePaymentServiceDefinitionSessionUnion",
    "Response403CreatePaymentServiceSession",
    "Response403CreatePaymentServiceSessionUnion",
    "Response403CreatePaymentServiceUnion",
    "Response403CreatePayout",
    "Response403CreatePayoutUnion",
    "Response403CreateTransaction",
    "Response403CreateTransactionRefund",
    "Response403CreateTransactionRefundUnion",
    "Response403CreateTransactionUnion",
    "Response403DeleteBuyer",
    "Response403DeleteBuyerShippingDetails",
    "Response403DeleteBuyerShippingDetailsUnion",
    "Response403DeleteBuyerUnion",
    "Response403DeleteCheckoutSession",
    "Response403DeleteCheckoutSessionUnion",
    "Response403DeleteDigitalWallet",
    "Response403DeleteDigitalWalletUnion",
    "Response403DeleteGiftCard",
    "Response403DeleteGiftCardUnion",
    "Response403DeletePaymentMethod",
    "Response403DeletePaymentMethodNetworkToken",
    "Response403DeletePaymentMethodNetworkTokenUnion",
    "Response403DeletePaymentMethodPaymentServiceToken",
    "Response403DeletePaymentMethodPaymentServiceTokenUnion",
    "Response403DeletePaymentMethodUnion",
    "Response403DeletePaymentService",
    "Response403DeletePaymentServiceUnion",
    "Response403GetBuyer",
    "Response403GetBuyerShippingDetails",
    "Response403GetBuyerShippingDetailsUnion",
    "Response403GetBuyerUnion",
    "Response403GetCheckoutSession",
    "Response403GetCheckoutSessionUnion",
    "Response403GetDigitalWallet",
    "Response403GetDigitalWalletUnion",
    "Response403GetGiftCard",
    "Response403GetGiftCardUnion",
    "Response403GetMerchantAccount",
    "Response403GetMerchantAccountUnion",
    "Response403GetPaymentMethod",
    "Response403GetPaymentMethodUnion",
    "Response403GetPaymentService",
    "Response403GetPaymentServiceDefinition",
    "Response403GetPaymentServiceDefinitionUnion",
    "Response403GetPaymentServiceUnion",
    "Response403GetPayout",
    "Response403GetPayoutUnion",
    "Response403GetRefund",
    "Response403GetRefundUnion",
    "Response403GetTransaction",
    "Response403GetTransactionRefund",
    "Response403GetTransactionRefundUnion",
    "Response403GetTransactionSummary",
    "Response403GetTransactionSummaryUnion",
    "Response403GetTransactionUnion",
    "Response403ListAuditLogs",
    "Response403ListAuditLogsUnion",
    "Response403ListBuyerGiftCards",
    "Response403ListBuyerGiftCardsUnion",
    "Response403ListBuyerPaymentMethods",
    "Response403ListBuyerPaymentMethodsUnion",
    "Response403ListBuyerShippingDetails",
    "Response403ListBuyerShippingDetailsUnion",
    "Response403ListBuyers",
    "Response403ListBuyersUnion",
    "Response403ListCardSchemeDefinitions",
    "Response403ListCardSchemeDefinitionsUnion",
    "Response403ListDigitalWallets",
    "Response403ListDigitalWalletsUnion",
    "Response403ListGiftCardBalances",
    "Response403ListGiftCardBalancesUnion",
    "Response403ListGiftCards",
    "Response403ListGiftCardsUnion",
    "Response403ListMerchantAccounts",
    "Response403ListMerchantAccountsUnion",
    "Response403ListPaymentMethodNetworkTokens",
    "Response403ListPaymentMethodNetworkTokensUnion",
    "Response403ListPaymentMethodPaymentServiceTokens",
    "Response403ListPaymentMethodPaymentServiceTokensUnion",
    "Response403ListPaymentMethods",
    "Response403ListPaymentMethodsUnion",
    "Response403ListPaymentOptions",
    "Response403ListPaymentOptionsUnion",
    "Response403ListPaymentServiceDefinitions",
    "Response403ListPaymentServiceDefinitionsUnion",
    "Response403ListPaymentServices",
    "Response403ListPaymentServicesUnion",
    "Response403ListPayouts",
    "Response403ListPayoutsUnion",
    "Response403ListTransactionRefunds",
    "Response403ListTransactionRefundsUnion",
    "Response403ListTransactions",
    "Response403ListTransactionsUnion",
    "Response403RegisterDigitalWalletDomain",
    "Response403RegisterDigitalWalletDomainUnion",
    "Response403ResumePaymentMethodNetworkToken",
    "Response403ResumePaymentMethodNetworkTokenUnion",
    "Response403SuspendPaymentMethodNetworkToken",
    "Response403SuspendPaymentMethodNetworkTokenUnion",
    "Response403SyncTransaction",
    "Response403SyncTransactionUnion",
    "Response403UnregisterDigitalWalletDomain",
    "Response403UnregisterDigitalWalletDomainUnion",
    "Response403UpdateBuyer",
    "Response403UpdateBuyerShippingDetails",
    "Response403UpdateBuyerShippingDetailsUnion",
    "Response403UpdateBuyerUnion",
    "Response403UpdateCheckoutSession",
    "Response403UpdateCheckoutSessionUnion",
    "Response403UpdateDigitalWallet",
    "Response403UpdateDigitalWalletUnion",
    "Response403UpdateMerchantAccount",
    "Response403UpdateMerchantAccountUnion",
    "Response403UpdatePaymentService",
    "Response403UpdatePaymentServiceUnion",
    "Response403VerifyPaymentServiceCredentials",
    "Response403VerifyPaymentServiceCredentialsUnion",
    "Response403VoidTransaction",
    "Response403VoidTransactionUnion",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .error403 import Error403Data
from .error403active import Error403ActiveData
from .error403forbidden import Error403ForbiddenData
from gr4vy import utils
from typing import Union
from typing_extensions import TypeAliasType


Response403RegisterDigitalWalletDomainUnion = TypeAliasType(
    "Response403RegisterDigitalWalletDomainUnion",
    Union[Error403Data, Error403ForbiddenData, Error403ActiveData],
)
r"""The credentials were invalid or the caller did not have permission to act on the resource."""


class Response403RegisterDigitalWalletDomain(Exception):
    r"""The credentials were invalid or the caller did not have permission to act on the resource."""

    data: Response403RegisterDigitalWalletDomainUnion

    def __init__(self, data: Response403RegisterDigitalWalletDomainUnion):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(
            self.data, Response403RegisterDigitalWalletDomainUnion
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


PaymentMethodStatus = Union[
    Literal["processing", "buyer_approval_required", "succeeded", "failed", "paused"],
    UnrecognizedStr,
]
